#########
Abjad API
#########

*************************
Core composition packages
*************************

:py:mod:`chordtools <abjad.tools.chordtools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/chordtools/index

   .. toctree::
      :maxdepth: 1

      tools/chordtools/Chord/Chord

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/chordtools/Chord/Chord

:py:mod:`componenttools <abjad.tools.componenttools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/componenttools/index

   .. toctree::
      :maxdepth: 1

      tools/componenttools/Component/Component

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/componenttools/Component/Component

:py:mod:`containertools <abjad.tools.containertools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/containertools/index

   .. toctree::
      :maxdepth: 1

      tools/containertools/Cluster/Cluster
      tools/containertools/Container/Container
      tools/containertools/FixedDurationContainer/FixedDurationContainer
      tools/containertools/GraceContainer/GraceContainer

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/containertools/Cluster/Cluster
      tools/containertools/Container/Container
      tools/containertools/FixedDurationContainer/FixedDurationContainer
      tools/containertools/GraceContainer/GraceContainer

:py:mod:`contexttools <abjad.tools.contexttools>`
=================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/contexttools/index

   .. toctree::
      :maxdepth: 1

      tools/contexttools/ClefMark/ClefMark
      tools/contexttools/ClefMarkInventory/ClefMarkInventory
      tools/contexttools/Context/Context
      tools/contexttools/ContextMark/ContextMark
      tools/contexttools/DynamicMark/DynamicMark
      tools/contexttools/KeySignatureMark/KeySignatureMark
      tools/contexttools/StaffChangeMark/StaffChangeMark
      tools/contexttools/TempoMark/TempoMark
      tools/contexttools/TempoMarkInventory/TempoMarkInventory
      tools/contexttools/TimeSignatureMark/TimeSignatureMark

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/contexttools/ClefMark/ClefMark
      tools/contexttools/ClefMarkInventory/ClefMarkInventory
      tools/contexttools/Context/Context
      tools/contexttools/ContextMark/ContextMark
      tools/contexttools/DynamicMark/DynamicMark
      tools/contexttools/KeySignatureMark/KeySignatureMark
      tools/contexttools/StaffChangeMark/StaffChangeMark
      tools/contexttools/TempoMark/TempoMark
      tools/contexttools/TempoMarkInventory/TempoMarkInventory
      tools/contexttools/TimeSignatureMark/TimeSignatureMark

:py:mod:`durationtools <abjad.tools.durationtools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/durationtools/index

   .. toctree::
      :maxdepth: 1

      tools/durationtools/Duration/Duration
      tools/durationtools/Multiplier/Multiplier
      tools/durationtools/Offset/Offset

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/durationtools/Duration/Duration
      tools/durationtools/Multiplier/Multiplier
      tools/durationtools/Offset/Offset

:py:mod:`instrumenttools <abjad.tools.instrumenttools>`
=======================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/instrumenttools/index

   .. toctree::
      :maxdepth: 1

      tools/instrumenttools/Accordion/Accordion
      tools/instrumenttools/AltoFlute/AltoFlute
      tools/instrumenttools/AltoSaxophone/AltoSaxophone
      tools/instrumenttools/AltoTrombone/AltoTrombone
      tools/instrumenttools/BFlatClarinet/BFlatClarinet
      tools/instrumenttools/BaritoneSaxophone/BaritoneSaxophone
      tools/instrumenttools/BaritoneVoice/BaritoneVoice
      tools/instrumenttools/BassClarinet/BassClarinet
      tools/instrumenttools/BassFlute/BassFlute
      tools/instrumenttools/BassSaxophone/BassSaxophone
      tools/instrumenttools/BassTrombone/BassTrombone
      tools/instrumenttools/BassVoice/BassVoice
      tools/instrumenttools/Bassoon/Bassoon
      tools/instrumenttools/Cello/Cello
      tools/instrumenttools/ClarinetInA/ClarinetInA
      tools/instrumenttools/Contrabass/Contrabass
      tools/instrumenttools/ContrabassClarinet/ContrabassClarinet
      tools/instrumenttools/ContrabassFlute/ContrabassFlute
      tools/instrumenttools/ContrabassSaxophone/ContrabassSaxophone
      tools/instrumenttools/Contrabassoon/Contrabassoon
      tools/instrumenttools/ContraltoVoice/ContraltoVoice
      tools/instrumenttools/EFlatClarinet/EFlatClarinet
      tools/instrumenttools/EnglishHorn/EnglishHorn
      tools/instrumenttools/Flute/Flute
      tools/instrumenttools/FrenchHorn/FrenchHorn
      tools/instrumenttools/Glockenspiel/Glockenspiel
      tools/instrumenttools/Guitar/Guitar
      tools/instrumenttools/Harp/Harp
      tools/instrumenttools/Harpsichord/Harpsichord
      tools/instrumenttools/Instrument/Instrument
      tools/instrumenttools/InstrumentInventory/InstrumentInventory
      tools/instrumenttools/Marimba/Marimba
      tools/instrumenttools/MezzoSopranoVoice/MezzoSopranoVoice
      tools/instrumenttools/Oboe/Oboe
      tools/instrumenttools/Piano/Piano
      tools/instrumenttools/Piccolo/Piccolo
      tools/instrumenttools/SopraninoSaxophone/SopraninoSaxophone
      tools/instrumenttools/SopranoSaxophone/SopranoSaxophone
      tools/instrumenttools/SopranoVoice/SopranoVoice
      tools/instrumenttools/TenorSaxophone/TenorSaxophone
      tools/instrumenttools/TenorTrombone/TenorTrombone
      tools/instrumenttools/TenorVoice/TenorVoice
      tools/instrumenttools/Trumpet/Trumpet
      tools/instrumenttools/Tuba/Tuba
      tools/instrumenttools/UntunedPercussion/UntunedPercussion
      tools/instrumenttools/Vibraphone/Vibraphone
      tools/instrumenttools/Viola/Viola
      tools/instrumenttools/Violin/Violin
      tools/instrumenttools/WoodwindFingering/WoodwindFingering
      tools/instrumenttools/Xylophone/Xylophone

   .. toctree::
      :maxdepth: 1

      tools/instrumenttools/default_instrument_name_to_instrument_class
      tools/instrumenttools/iterate_out_of_range_notes_and_chords
      tools/instrumenttools/notes_and_chords_are_in_range
      tools/instrumenttools/notes_and_chords_are_on_expected_clefs
      tools/instrumenttools/transpose_from_sounding_pitch_to_written_pitch
      tools/instrumenttools/transpose_from_written_pitch_to_sounding_pitch

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/instrumenttools/Accordion/Accordion
      tools/instrumenttools/AltoFlute/AltoFlute
      tools/instrumenttools/AltoSaxophone/AltoSaxophone
      tools/instrumenttools/AltoTrombone/AltoTrombone
      tools/instrumenttools/BFlatClarinet/BFlatClarinet
      tools/instrumenttools/BaritoneSaxophone/BaritoneSaxophone
      tools/instrumenttools/BaritoneVoice/BaritoneVoice
      tools/instrumenttools/BassClarinet/BassClarinet
      tools/instrumenttools/BassFlute/BassFlute
      tools/instrumenttools/BassSaxophone/BassSaxophone
      tools/instrumenttools/BassTrombone/BassTrombone
      tools/instrumenttools/BassVoice/BassVoice
      tools/instrumenttools/Bassoon/Bassoon
      tools/instrumenttools/Cello/Cello
      tools/instrumenttools/ClarinetInA/ClarinetInA
      tools/instrumenttools/Contrabass/Contrabass
      tools/instrumenttools/ContrabassClarinet/ContrabassClarinet
      tools/instrumenttools/ContrabassFlute/ContrabassFlute
      tools/instrumenttools/ContrabassSaxophone/ContrabassSaxophone
      tools/instrumenttools/Contrabassoon/Contrabassoon
      tools/instrumenttools/ContraltoVoice/ContraltoVoice
      tools/instrumenttools/EFlatClarinet/EFlatClarinet
      tools/instrumenttools/EnglishHorn/EnglishHorn
      tools/instrumenttools/Flute/Flute
      tools/instrumenttools/FrenchHorn/FrenchHorn
      tools/instrumenttools/Glockenspiel/Glockenspiel
      tools/instrumenttools/Guitar/Guitar
      tools/instrumenttools/Harp/Harp
      tools/instrumenttools/Harpsichord/Harpsichord
      tools/instrumenttools/Instrument/Instrument
      tools/instrumenttools/InstrumentInventory/InstrumentInventory
      tools/instrumenttools/Marimba/Marimba
      tools/instrumenttools/MezzoSopranoVoice/MezzoSopranoVoice
      tools/instrumenttools/Oboe/Oboe
      tools/instrumenttools/Piano/Piano
      tools/instrumenttools/Piccolo/Piccolo
      tools/instrumenttools/SopraninoSaxophone/SopraninoSaxophone
      tools/instrumenttools/SopranoSaxophone/SopranoSaxophone
      tools/instrumenttools/SopranoVoice/SopranoVoice
      tools/instrumenttools/TenorSaxophone/TenorSaxophone
      tools/instrumenttools/TenorTrombone/TenorTrombone
      tools/instrumenttools/TenorVoice/TenorVoice
      tools/instrumenttools/Trumpet/Trumpet
      tools/instrumenttools/Tuba/Tuba
      tools/instrumenttools/UntunedPercussion/UntunedPercussion
      tools/instrumenttools/Vibraphone/Vibraphone
      tools/instrumenttools/Viola/Viola
      tools/instrumenttools/Violin/Violin
      tools/instrumenttools/WoodwindFingering/WoodwindFingering
      tools/instrumenttools/Xylophone/Xylophone

   Functions
   ---------

   .. toctree::

      tools/instrumenttools/default_instrument_name_to_instrument_class
      tools/instrumenttools/iterate_out_of_range_notes_and_chords
      tools/instrumenttools/notes_and_chords_are_in_range
      tools/instrumenttools/notes_and_chords_are_on_expected_clefs
      tools/instrumenttools/transpose_from_sounding_pitch_to_written_pitch
      tools/instrumenttools/transpose_from_written_pitch_to_sounding_pitch

:py:mod:`iotools <abjad.tools.iotools>`
=======================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/iotools/index

   .. toctree::
      :maxdepth: 1

      tools/iotools/RedirectedStreams/RedirectedStreams

   .. toctree::
      :maxdepth: 1

      tools/iotools/clear_terminal
      tools/iotools/count_function_calls
      tools/iotools/f
      tools/iotools/get_last_output_file_name
      tools/iotools/get_next_output_file_name
      tools/iotools/graph
      tools/iotools/insert_expr_into_lilypond_file
      tools/iotools/log
      tools/iotools/log_render_lilypond_input
      tools/iotools/ly
      tools/iotools/open_file
      tools/iotools/p
      tools/iotools/pdf
      tools/iotools/play
      tools/iotools/plot
      tools/iotools/profile_expr
      tools/iotools/redo
      tools/iotools/run_abjad
      tools/iotools/run_lilypond
      tools/iotools/save_last_ly_as
      tools/iotools/save_last_pdf_as
      tools/iotools/show
      tools/iotools/spawn_subprocess
      tools/iotools/verify_output_directory
      tools/iotools/warn_almost_full
      tools/iotools/which
      tools/iotools/write_expr_to_ly
      tools/iotools/write_expr_to_pdf
      tools/iotools/z

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/iotools/RedirectedStreams/RedirectedStreams

   Functions
   ---------

   .. toctree::

      tools/iotools/clear_terminal
      tools/iotools/count_function_calls
      tools/iotools/f
      tools/iotools/get_last_output_file_name
      tools/iotools/get_next_output_file_name
      tools/iotools/graph
      tools/iotools/insert_expr_into_lilypond_file
      tools/iotools/log
      tools/iotools/log_render_lilypond_input
      tools/iotools/ly
      tools/iotools/open_file
      tools/iotools/p
      tools/iotools/pdf
      tools/iotools/play
      tools/iotools/plot
      tools/iotools/profile_expr
      tools/iotools/redo
      tools/iotools/run_abjad
      tools/iotools/run_lilypond
      tools/iotools/save_last_ly_as
      tools/iotools/save_last_pdf_as
      tools/iotools/show
      tools/iotools/spawn_subprocess
      tools/iotools/verify_output_directory
      tools/iotools/warn_almost_full
      tools/iotools/which
      tools/iotools/write_expr_to_ly
      tools/iotools/write_expr_to_pdf
      tools/iotools/z

:py:mod:`iterationtools <abjad.tools.iterationtools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/iterationtools/index

   .. toctree::
      :maxdepth: 1

      tools/iterationtools/iterate_chords_in_expr
      tools/iterationtools/iterate_components_and_grace_containers_in_expr
      tools/iterationtools/iterate_components_depth_first
      tools/iterationtools/iterate_components_in_expr
      tools/iterationtools/iterate_containers_in_expr
      tools/iterationtools/iterate_contexts_in_expr
      tools/iterationtools/iterate_leaf_pairs_in_expr
      tools/iterationtools/iterate_leaves_in_expr
      tools/iterationtools/iterate_logical_voice_from_component
      tools/iterationtools/iterate_logical_voice_in_expr
      tools/iterationtools/iterate_measures_in_expr
      tools/iterationtools/iterate_nontrivial_tie_chains_in_expr
      tools/iterationtools/iterate_notes_and_chords_in_expr
      tools/iterationtools/iterate_notes_in_expr
      tools/iterationtools/iterate_pitched_tie_chains_in_expr
      tools/iterationtools/iterate_rests_in_expr
      tools/iterationtools/iterate_runs_in_expr
      tools/iterationtools/iterate_scores_in_expr
      tools/iterationtools/iterate_semantic_voices_in_expr
      tools/iterationtools/iterate_skips_in_expr
      tools/iterationtools/iterate_staves_in_expr
      tools/iterationtools/iterate_tie_chains_in_expr
      tools/iterationtools/iterate_timeline_from_component
      tools/iterationtools/iterate_timeline_in_expr
      tools/iterationtools/iterate_topmost_tie_chains_and_components_in_expr
      tools/iterationtools/iterate_tuplets_in_expr
      tools/iterationtools/iterate_vertical_moments_in_expr
      tools/iterationtools/iterate_voices_in_expr

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/iterationtools/iterate_chords_in_expr
      tools/iterationtools/iterate_components_and_grace_containers_in_expr
      tools/iterationtools/iterate_components_depth_first
      tools/iterationtools/iterate_components_in_expr
      tools/iterationtools/iterate_containers_in_expr
      tools/iterationtools/iterate_contexts_in_expr
      tools/iterationtools/iterate_leaf_pairs_in_expr
      tools/iterationtools/iterate_leaves_in_expr
      tools/iterationtools/iterate_logical_voice_from_component
      tools/iterationtools/iterate_logical_voice_in_expr
      tools/iterationtools/iterate_measures_in_expr
      tools/iterationtools/iterate_nontrivial_tie_chains_in_expr
      tools/iterationtools/iterate_notes_and_chords_in_expr
      tools/iterationtools/iterate_notes_in_expr
      tools/iterationtools/iterate_pitched_tie_chains_in_expr
      tools/iterationtools/iterate_rests_in_expr
      tools/iterationtools/iterate_runs_in_expr
      tools/iterationtools/iterate_scores_in_expr
      tools/iterationtools/iterate_semantic_voices_in_expr
      tools/iterationtools/iterate_skips_in_expr
      tools/iterationtools/iterate_staves_in_expr
      tools/iterationtools/iterate_tie_chains_in_expr
      tools/iterationtools/iterate_timeline_from_component
      tools/iterationtools/iterate_timeline_in_expr
      tools/iterationtools/iterate_topmost_tie_chains_and_components_in_expr
      tools/iterationtools/iterate_tuplets_in_expr
      tools/iterationtools/iterate_vertical_moments_in_expr
      tools/iterationtools/iterate_voices_in_expr

:py:mod:`labeltools <abjad.tools.labeltools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/labeltools/index

   .. toctree::
      :maxdepth: 1

      tools/labeltools/color_chord_note_heads_in_expr_by_pitch_class_color_map
      tools/labeltools/color_contents_of_container
      tools/labeltools/color_leaf
      tools/labeltools/color_leaves_in_expr
      tools/labeltools/color_measure
      tools/labeltools/color_measures_with_non_power_of_two_denominators_in_expr
      tools/labeltools/color_note_head_by_numbered_pitch_class_color_map
      tools/labeltools/label_leaves_in_expr_with_leaf_depth
      tools/labeltools/label_leaves_in_expr_with_leaf_duration
      tools/labeltools/label_leaves_in_expr_with_leaf_durations
      tools/labeltools/label_leaves_in_expr_with_leaf_indices
      tools/labeltools/label_leaves_in_expr_with_leaf_numbers
      tools/labeltools/label_leaves_in_expr_with_named_interval_classes
      tools/labeltools/label_leaves_in_expr_with_named_intervals
      tools/labeltools/label_leaves_in_expr_with_numbered_interval_classes
      tools/labeltools/label_leaves_in_expr_with_numbered_intervals
      tools/labeltools/label_leaves_in_expr_with_numbered_inversion_equivalent_interval_classes
      tools/labeltools/label_leaves_in_expr_with_pitch_class_numbers
      tools/labeltools/label_leaves_in_expr_with_pitch_numbers
      tools/labeltools/label_leaves_in_expr_with_tuplet_depth
      tools/labeltools/label_leaves_in_expr_with_written_leaf_duration
      tools/labeltools/label_notes_in_expr_with_note_indices
      tools/labeltools/label_tie_chains_in_expr_with_tie_chain_duration
      tools/labeltools/label_tie_chains_in_expr_with_tie_chain_durations
      tools/labeltools/label_tie_chains_in_expr_with_written_tie_chain_duration
      tools/labeltools/label_vertical_moments_in_expr_with_interval_class_vectors
      tools/labeltools/label_vertical_moments_in_expr_with_named_intervals
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_interval_classes
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_intervals
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_pitch_classes
      tools/labeltools/label_vertical_moments_in_expr_with_pitch_numbers
      tools/labeltools/remove_markup_from_leaves_in_expr

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/labeltools/color_chord_note_heads_in_expr_by_pitch_class_color_map
      tools/labeltools/color_contents_of_container
      tools/labeltools/color_leaf
      tools/labeltools/color_leaves_in_expr
      tools/labeltools/color_measure
      tools/labeltools/color_measures_with_non_power_of_two_denominators_in_expr
      tools/labeltools/color_note_head_by_numbered_pitch_class_color_map
      tools/labeltools/label_leaves_in_expr_with_leaf_depth
      tools/labeltools/label_leaves_in_expr_with_leaf_duration
      tools/labeltools/label_leaves_in_expr_with_leaf_durations
      tools/labeltools/label_leaves_in_expr_with_leaf_indices
      tools/labeltools/label_leaves_in_expr_with_leaf_numbers
      tools/labeltools/label_leaves_in_expr_with_named_interval_classes
      tools/labeltools/label_leaves_in_expr_with_named_intervals
      tools/labeltools/label_leaves_in_expr_with_numbered_interval_classes
      tools/labeltools/label_leaves_in_expr_with_numbered_intervals
      tools/labeltools/label_leaves_in_expr_with_numbered_inversion_equivalent_interval_classes
      tools/labeltools/label_leaves_in_expr_with_pitch_class_numbers
      tools/labeltools/label_leaves_in_expr_with_pitch_numbers
      tools/labeltools/label_leaves_in_expr_with_tuplet_depth
      tools/labeltools/label_leaves_in_expr_with_written_leaf_duration
      tools/labeltools/label_notes_in_expr_with_note_indices
      tools/labeltools/label_tie_chains_in_expr_with_tie_chain_duration
      tools/labeltools/label_tie_chains_in_expr_with_tie_chain_durations
      tools/labeltools/label_tie_chains_in_expr_with_written_tie_chain_duration
      tools/labeltools/label_vertical_moments_in_expr_with_interval_class_vectors
      tools/labeltools/label_vertical_moments_in_expr_with_named_intervals
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_interval_classes
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_intervals
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_pitch_classes
      tools/labeltools/label_vertical_moments_in_expr_with_pitch_numbers
      tools/labeltools/remove_markup_from_leaves_in_expr

:py:mod:`layouttools <abjad.tools.layouttools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/layouttools/index

   .. toctree::
      :maxdepth: 1

      tools/layouttools/SpacingIndication/SpacingIndication

   .. toctree::
      :maxdepth: 1

      tools/layouttools/make_spacing_vector
      tools/layouttools/set_line_breaks_by_line_duration
      tools/layouttools/set_line_breaks_cyclically_by_line_duration_ge
      tools/layouttools/set_line_breaks_cyclically_by_line_duration_in_seconds_ge

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/layouttools/SpacingIndication/SpacingIndication

   Functions
   ---------

   .. toctree::

      tools/layouttools/make_spacing_vector
      tools/layouttools/set_line_breaks_by_line_duration
      tools/layouttools/set_line_breaks_cyclically_by_line_duration_ge
      tools/layouttools/set_line_breaks_cyclically_by_line_duration_in_seconds_ge

:py:mod:`leaftools <abjad.tools.leaftools>`
===========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/leaftools/index

   .. toctree::
      :maxdepth: 1

      tools/leaftools/Leaf/Leaf

   .. toctree::
      :maxdepth: 1

      tools/leaftools/make_leaves
      tools/leaftools/make_leaves_from_talea
      tools/leaftools/make_tied_leaf

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/leaftools/Leaf/Leaf

   Functions
   ---------

   .. toctree::

      tools/leaftools/make_leaves
      tools/leaftools/make_leaves_from_talea
      tools/leaftools/make_tied_leaf

:py:mod:`lilypondfiletools <abjad.tools.lilypondfiletools>`
===========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/lilypondfiletools/index

   .. toctree::
      :maxdepth: 1

      tools/lilypondfiletools/AttributedBlock/AttributedBlock
      tools/lilypondfiletools/NonattributedBlock/NonattributedBlock

   .. toctree::
      :maxdepth: 1

      tools/lilypondfiletools/AbjadRevisionToken/AbjadRevisionToken
      tools/lilypondfiletools/BookBlock/BookBlock
      tools/lilypondfiletools/BookpartBlock/BookpartBlock
      tools/lilypondfiletools/ContextBlock/ContextBlock
      tools/lilypondfiletools/DateTimeToken/DateTimeToken
      tools/lilypondfiletools/HeaderBlock/HeaderBlock
      tools/lilypondfiletools/LayoutBlock/LayoutBlock
      tools/lilypondfiletools/LilyPondDimension/LilyPondDimension
      tools/lilypondfiletools/LilyPondFile/LilyPondFile
      tools/lilypondfiletools/LilyPondLanguageToken/LilyPondLanguageToken
      tools/lilypondfiletools/LilyPondVersionToken/LilyPondVersionToken
      tools/lilypondfiletools/MIDIBlock/MIDIBlock
      tools/lilypondfiletools/PaperBlock/PaperBlock
      tools/lilypondfiletools/ScoreBlock/ScoreBlock

   .. toctree::
      :maxdepth: 1

      tools/lilypondfiletools/make_basic_lilypond_file
      tools/lilypondfiletools/make_floating_time_signature_lilypond_file
      tools/lilypondfiletools/make_time_signature_context_block

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/lilypondfiletools/AttributedBlock/AttributedBlock
      tools/lilypondfiletools/NonattributedBlock/NonattributedBlock

   Concrete classes
   ----------------

   .. toctree::

      tools/lilypondfiletools/AbjadRevisionToken/AbjadRevisionToken
      tools/lilypondfiletools/BookBlock/BookBlock
      tools/lilypondfiletools/BookpartBlock/BookpartBlock
      tools/lilypondfiletools/ContextBlock/ContextBlock
      tools/lilypondfiletools/DateTimeToken/DateTimeToken
      tools/lilypondfiletools/HeaderBlock/HeaderBlock
      tools/lilypondfiletools/LayoutBlock/LayoutBlock
      tools/lilypondfiletools/LilyPondDimension/LilyPondDimension
      tools/lilypondfiletools/LilyPondFile/LilyPondFile
      tools/lilypondfiletools/LilyPondLanguageToken/LilyPondLanguageToken
      tools/lilypondfiletools/LilyPondVersionToken/LilyPondVersionToken
      tools/lilypondfiletools/MIDIBlock/MIDIBlock
      tools/lilypondfiletools/PaperBlock/PaperBlock
      tools/lilypondfiletools/ScoreBlock/ScoreBlock

   Functions
   ---------

   .. toctree::

      tools/lilypondfiletools/make_basic_lilypond_file
      tools/lilypondfiletools/make_floating_time_signature_lilypond_file
      tools/lilypondfiletools/make_time_signature_context_block

:py:mod:`marktools <abjad.tools.marktools>`
===========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/marktools/index

   .. toctree::
      :maxdepth: 1

      tools/marktools/DirectedMark/DirectedMark

   .. toctree::
      :maxdepth: 1

      tools/marktools/Annotation/Annotation
      tools/marktools/Articulation/Articulation
      tools/marktools/BarLine/BarLine
      tools/marktools/BendAfter/BendAfter
      tools/marktools/LilyPondCommandMark/LilyPondCommandMark
      tools/marktools/LilyPondComment/LilyPondComment
      tools/marktools/Mark/Mark
      tools/marktools/StemTremolo/StemTremolo

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/marktools/DirectedMark/DirectedMark

   Concrete classes
   ----------------

   .. toctree::

      tools/marktools/Annotation/Annotation
      tools/marktools/Articulation/Articulation
      tools/marktools/BarLine/BarLine
      tools/marktools/BendAfter/BendAfter
      tools/marktools/LilyPondCommandMark/LilyPondCommandMark
      tools/marktools/LilyPondComment/LilyPondComment
      tools/marktools/Mark/Mark
      tools/marktools/StemTremolo/StemTremolo

:py:mod:`markuptools <abjad.tools.markuptools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/markuptools/index

   .. toctree::
      :maxdepth: 1

      tools/markuptools/Markup/Markup
      tools/markuptools/MarkupCommand/MarkupCommand
      tools/markuptools/MarkupInventory/MarkupInventory
      tools/markuptools/MusicGlyph/MusicGlyph

   .. toctree::
      :maxdepth: 1

      tools/markuptools/combine_markup_commands
      tools/markuptools/make_big_centered_page_number_markup
      tools/markuptools/make_blank_line_markup
      tools/markuptools/make_centered_title_markup
      tools/markuptools/make_vertically_adjusted_composer_markup

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/markuptools/Markup/Markup
      tools/markuptools/MarkupCommand/MarkupCommand
      tools/markuptools/MarkupInventory/MarkupInventory
      tools/markuptools/MusicGlyph/MusicGlyph

   Functions
   ---------

   .. toctree::

      tools/markuptools/combine_markup_commands
      tools/markuptools/make_big_centered_page_number_markup
      tools/markuptools/make_blank_line_markup
      tools/markuptools/make_centered_title_markup
      tools/markuptools/make_vertically_adjusted_composer_markup

:py:mod:`mathtools <abjad.tools.mathtools>`
===========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/mathtools/index

   .. toctree::
      :maxdepth: 1

      tools/mathtools/BoundedObject/BoundedObject
      tools/mathtools/Infinity/Infinity
      tools/mathtools/NegativeInfinity/NegativeInfinity
      tools/mathtools/NonreducedFraction/NonreducedFraction
      tools/mathtools/NonreducedRatio/NonreducedRatio
      tools/mathtools/Ratio/Ratio

   .. toctree::
      :maxdepth: 1

      tools/mathtools/are_relatively_prime
      tools/mathtools/arithmetic_mean
      tools/mathtools/binomial_coefficient
      tools/mathtools/cumulative_products
      tools/mathtools/cumulative_signed_weights
      tools/mathtools/cumulative_sums
      tools/mathtools/cumulative_sums_zero
      tools/mathtools/cumulative_sums_zero_pairwise
      tools/mathtools/difference_series
      tools/mathtools/divide_number_by_ratio
      tools/mathtools/divisors
      tools/mathtools/factors
      tools/mathtools/fraction_to_proper_fraction
      tools/mathtools/get_shared_numeric_sign
      tools/mathtools/greatest_common_divisor
      tools/mathtools/greatest_multiple_less_equal
      tools/mathtools/greatest_power_of_two_less_equal
      tools/mathtools/integer_equivalent_number_to_integer
      tools/mathtools/integer_to_base_k_tuple
      tools/mathtools/integer_to_binary_string
      tools/mathtools/interpolate_cosine
      tools/mathtools/interpolate_divide
      tools/mathtools/interpolate_divide_multiple
      tools/mathtools/interpolate_exponential
      tools/mathtools/interpolate_linear
      tools/mathtools/interval_string_to_pair_and_indicators
      tools/mathtools/is_assignable_integer
      tools/mathtools/is_dotted_integer
      tools/mathtools/is_integer_equivalent_expr
      tools/mathtools/is_integer_equivalent_number
      tools/mathtools/is_negative_integer
      tools/mathtools/is_nonnegative_integer
      tools/mathtools/is_nonnegative_integer_equivalent_number
      tools/mathtools/is_nonnegative_integer_power_of_two
      tools/mathtools/is_positive_integer
      tools/mathtools/is_positive_integer_equivalent_number
      tools/mathtools/is_positive_integer_power_of_two
      tools/mathtools/least_common_multiple
      tools/mathtools/least_multiple_greater_equal
      tools/mathtools/least_power_of_two_greater_equal
      tools/mathtools/next_integer_partition
      tools/mathtools/partition_integer_by_ratio
      tools/mathtools/partition_integer_into_canonic_parts
      tools/mathtools/partition_integer_into_halves
      tools/mathtools/partition_integer_into_parts_less_than_double
      tools/mathtools/partition_integer_into_units
      tools/mathtools/remove_powers_of_two
      tools/mathtools/sign
      tools/mathtools/weight
      tools/mathtools/yield_all_compositions_of_integer
      tools/mathtools/yield_all_partitions_of_integer
      tools/mathtools/yield_nonreduced_fractions

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/mathtools/BoundedObject/BoundedObject
      tools/mathtools/Infinity/Infinity
      tools/mathtools/NegativeInfinity/NegativeInfinity
      tools/mathtools/NonreducedFraction/NonreducedFraction
      tools/mathtools/NonreducedRatio/NonreducedRatio
      tools/mathtools/Ratio/Ratio

   Functions
   ---------

   .. toctree::

      tools/mathtools/are_relatively_prime
      tools/mathtools/arithmetic_mean
      tools/mathtools/binomial_coefficient
      tools/mathtools/cumulative_products
      tools/mathtools/cumulative_signed_weights
      tools/mathtools/cumulative_sums
      tools/mathtools/cumulative_sums_zero
      tools/mathtools/cumulative_sums_zero_pairwise
      tools/mathtools/difference_series
      tools/mathtools/divide_number_by_ratio
      tools/mathtools/divisors
      tools/mathtools/factors
      tools/mathtools/fraction_to_proper_fraction
      tools/mathtools/get_shared_numeric_sign
      tools/mathtools/greatest_common_divisor
      tools/mathtools/greatest_multiple_less_equal
      tools/mathtools/greatest_power_of_two_less_equal
      tools/mathtools/integer_equivalent_number_to_integer
      tools/mathtools/integer_to_base_k_tuple
      tools/mathtools/integer_to_binary_string
      tools/mathtools/interpolate_cosine
      tools/mathtools/interpolate_divide
      tools/mathtools/interpolate_divide_multiple
      tools/mathtools/interpolate_exponential
      tools/mathtools/interpolate_linear
      tools/mathtools/interval_string_to_pair_and_indicators
      tools/mathtools/is_assignable_integer
      tools/mathtools/is_dotted_integer
      tools/mathtools/is_integer_equivalent_expr
      tools/mathtools/is_integer_equivalent_number
      tools/mathtools/is_negative_integer
      tools/mathtools/is_nonnegative_integer
      tools/mathtools/is_nonnegative_integer_equivalent_number
      tools/mathtools/is_nonnegative_integer_power_of_two
      tools/mathtools/is_positive_integer
      tools/mathtools/is_positive_integer_equivalent_number
      tools/mathtools/is_positive_integer_power_of_two
      tools/mathtools/least_common_multiple
      tools/mathtools/least_multiple_greater_equal
      tools/mathtools/least_power_of_two_greater_equal
      tools/mathtools/next_integer_partition
      tools/mathtools/partition_integer_by_ratio
      tools/mathtools/partition_integer_into_canonic_parts
      tools/mathtools/partition_integer_into_halves
      tools/mathtools/partition_integer_into_parts_less_than_double
      tools/mathtools/partition_integer_into_units
      tools/mathtools/remove_powers_of_two
      tools/mathtools/sign
      tools/mathtools/weight
      tools/mathtools/yield_all_compositions_of_integer
      tools/mathtools/yield_all_partitions_of_integer
      tools/mathtools/yield_nonreduced_fractions

:py:mod:`measuretools <abjad.tools.measuretools>`
=================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/measuretools/index

   .. toctree::
      :maxdepth: 1

      tools/measuretools/Measure/Measure

   .. toctree::
      :maxdepth: 1

      tools/measuretools/append_spacer_skip_to_underfull_measure
      tools/measuretools/append_spacer_skips_to_underfull_measures_in_expr
      tools/measuretools/apply_full_measure_tuplets_to_contents_of_measures_in_expr
      tools/measuretools/extend_measures_in_expr_and_apply_full_measure_tuplets
      tools/measuretools/fill_measures_in_expr_with_full_measure_spacer_skips
      tools/measuretools/fill_measures_in_expr_with_minimal_number_of_notes
      tools/measuretools/fill_measures_in_expr_with_repeated_notes
      tools/measuretools/fill_measures_in_expr_with_time_signature_denominator_notes
      tools/measuretools/get_measure_that_starts_with_container
      tools/measuretools/get_measure_that_stops_with_container
      tools/measuretools/get_next_measure_from_component
      tools/measuretools/get_one_indexed_measure_number_in_expr
      tools/measuretools/get_previous_measure_from_component
      tools/measuretools/make_measures_with_full_measure_spacer_skips
      tools/measuretools/move_full_measure_tuplet_prolation_to_measure_time_signature
      tools/measuretools/move_measure_prolation_to_full_measure_tuplet
      tools/measuretools/replace_contents_of_measures_in_expr
      tools/measuretools/scale_measure_denominator_and_adjust_measure_contents
      tools/measuretools/set_always_format_time_signature_of_measures_in_expr
      tools/measuretools/set_measure_denominator_and_adjust_numerator

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/measuretools/Measure/Measure

   Functions
   ---------

   .. toctree::

      tools/measuretools/append_spacer_skip_to_underfull_measure
      tools/measuretools/append_spacer_skips_to_underfull_measures_in_expr
      tools/measuretools/apply_full_measure_tuplets_to_contents_of_measures_in_expr
      tools/measuretools/extend_measures_in_expr_and_apply_full_measure_tuplets
      tools/measuretools/fill_measures_in_expr_with_full_measure_spacer_skips
      tools/measuretools/fill_measures_in_expr_with_minimal_number_of_notes
      tools/measuretools/fill_measures_in_expr_with_repeated_notes
      tools/measuretools/fill_measures_in_expr_with_time_signature_denominator_notes
      tools/measuretools/get_measure_that_starts_with_container
      tools/measuretools/get_measure_that_stops_with_container
      tools/measuretools/get_next_measure_from_component
      tools/measuretools/get_one_indexed_measure_number_in_expr
      tools/measuretools/get_previous_measure_from_component
      tools/measuretools/make_measures_with_full_measure_spacer_skips
      tools/measuretools/move_full_measure_tuplet_prolation_to_measure_time_signature
      tools/measuretools/move_measure_prolation_to_full_measure_tuplet
      tools/measuretools/replace_contents_of_measures_in_expr
      tools/measuretools/scale_measure_denominator_and_adjust_measure_contents
      tools/measuretools/set_always_format_time_signature_of_measures_in_expr
      tools/measuretools/set_measure_denominator_and_adjust_numerator

:py:mod:`mutationtools <abjad.tools.mutationtools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/mutationtools/index

   .. toctree::
      :maxdepth: 1

      tools/mutationtools/AttributeInspectionAgent/AttributeInspectionAgent
      tools/mutationtools/ScoreMutationAgent/ScoreMutationAgent

   .. toctree::
      :maxdepth: 1

      tools/mutationtools/mutate

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/mutationtools/AttributeInspectionAgent/AttributeInspectionAgent
      tools/mutationtools/ScoreMutationAgent/ScoreMutationAgent

   Functions
   ---------

   .. toctree::

      tools/mutationtools/mutate

:py:mod:`notetools <abjad.tools.notetools>`
===========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/notetools/index

   .. toctree::
      :maxdepth: 1

      tools/notetools/Harmonic/Harmonic
      tools/notetools/NaturalHarmonic/NaturalHarmonic
      tools/notetools/Note/Note
      tools/notetools/NoteHead/NoteHead

   .. toctree::
      :maxdepth: 1

      tools/notetools/make_accelerating_notes_with_lilypond_multipliers
      tools/notetools/make_notes
      tools/notetools/make_notes_with_multiplied_durations
      tools/notetools/make_percussion_note
      tools/notetools/make_quarter_notes_with_lilypond_duration_multiplier
      tools/notetools/make_repeated_notes
      tools/notetools/make_repeated_notes_from_time_signature
      tools/notetools/make_repeated_notes_from_time_signatures
      tools/notetools/make_repeated_notes_with_shorter_notes_at_end

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/notetools/Harmonic/Harmonic
      tools/notetools/NaturalHarmonic/NaturalHarmonic
      tools/notetools/Note/Note
      tools/notetools/NoteHead/NoteHead

   Functions
   ---------

   .. toctree::

      tools/notetools/make_accelerating_notes_with_lilypond_multipliers
      tools/notetools/make_notes
      tools/notetools/make_notes_with_multiplied_durations
      tools/notetools/make_percussion_note
      tools/notetools/make_quarter_notes_with_lilypond_duration_multiplier
      tools/notetools/make_repeated_notes
      tools/notetools/make_repeated_notes_from_time_signature
      tools/notetools/make_repeated_notes_from_time_signatures
      tools/notetools/make_repeated_notes_with_shorter_notes_at_end

:py:mod:`pitcharraytools <abjad.tools.pitcharraytools>`
=======================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/pitcharraytools/index

   .. toctree::
      :maxdepth: 1

      tools/pitcharraytools/PitchArray/PitchArray
      tools/pitcharraytools/PitchArrayCell/PitchArrayCell
      tools/pitcharraytools/PitchArrayColumn/PitchArrayColumn
      tools/pitcharraytools/PitchArrayInventory/PitchArrayInventory
      tools/pitcharraytools/PitchArrayRow/PitchArrayRow

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/pitcharraytools/PitchArray/PitchArray
      tools/pitcharraytools/PitchArrayCell/PitchArrayCell
      tools/pitcharraytools/PitchArrayColumn/PitchArrayColumn
      tools/pitcharraytools/PitchArrayInventory/PitchArrayInventory
      tools/pitcharraytools/PitchArrayRow/PitchArrayRow

:py:mod:`pitchtools <abjad.tools.pitchtools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/pitchtools/index

   .. toctree::
      :maxdepth: 1

      tools/pitchtools/Interval/Interval
      tools/pitchtools/IntervalClass/IntervalClass
      tools/pitchtools/Pitch/Pitch
      tools/pitchtools/PitchClass/PitchClass
      tools/pitchtools/Segment/Segment
      tools/pitchtools/Set/Set
      tools/pitchtools/Vector/Vector

   .. toctree::
      :maxdepth: 1

      tools/pitchtools/Accidental/Accidental
      tools/pitchtools/IntervalClassSegment/IntervalClassSegment
      tools/pitchtools/IntervalClassSet/IntervalClassSet
      tools/pitchtools/IntervalClassVector/IntervalClassVector
      tools/pitchtools/IntervalSegment/IntervalSegment
      tools/pitchtools/IntervalSet/IntervalSet
      tools/pitchtools/IntervalVector/IntervalVector
      tools/pitchtools/NamedInterval/NamedInterval
      tools/pitchtools/NamedIntervalClass/NamedIntervalClass
      tools/pitchtools/NamedInversionEquivalentIntervalClass/NamedInversionEquivalentIntervalClass
      tools/pitchtools/NamedPitch/NamedPitch
      tools/pitchtools/NamedPitchClass/NamedPitchClass
      tools/pitchtools/NumberedInterval/NumberedInterval
      tools/pitchtools/NumberedIntervalClass/NumberedIntervalClass
      tools/pitchtools/NumberedInversionEquivalentIntervalClass/NumberedInversionEquivalentIntervalClass
      tools/pitchtools/NumberedPitch/NumberedPitch
      tools/pitchtools/NumberedPitchClass/NumberedPitchClass
      tools/pitchtools/NumberedPitchClassColorMap/NumberedPitchClassColorMap
      tools/pitchtools/Octave/Octave
      tools/pitchtools/OctaveTranspositionMapping/OctaveTranspositionMapping
      tools/pitchtools/OctaveTranspositionMappingComponent/OctaveTranspositionMappingComponent
      tools/pitchtools/OctaveTranspositionMappingInventory/OctaveTranspositionMappingInventory
      tools/pitchtools/PitchClassSegment/PitchClassSegment
      tools/pitchtools/PitchClassSet/PitchClassSet
      tools/pitchtools/PitchClassVector/PitchClassVector
      tools/pitchtools/PitchRange/PitchRange
      tools/pitchtools/PitchRangeInventory/PitchRangeInventory
      tools/pitchtools/PitchSegment/PitchSegment
      tools/pitchtools/PitchSet/PitchSet
      tools/pitchtools/PitchVector/PitchVector
      tools/pitchtools/TwelveToneRow/TwelveToneRow

   .. toctree::
      :maxdepth: 1

      tools/pitchtools/apply_accidental_to_named_pitch
      tools/pitchtools/clef_and_staff_position_number_to_named_pitch
      tools/pitchtools/contains_subsegment
      tools/pitchtools/get_named_pitch_from_pitch_carrier
      tools/pitchtools/get_numbered_pitch_class_from_pitch_carrier
      tools/pitchtools/insert_and_transpose_nested_subruns_in_pitch_class_number_list
      tools/pitchtools/instantiate_pitch_and_interval_test_collection
      tools/pitchtools/inventory_aggregate_subsets
      tools/pitchtools/iterate_named_pitch_pairs_in_expr
      tools/pitchtools/list_named_pitches_in_expr
      tools/pitchtools/list_numbered_interval_numbers_pairwise
      tools/pitchtools/list_numbered_inversion_equivalent_interval_classes_pairwise
      tools/pitchtools/list_octave_transpositions_of_pitch_carrier_within_pitch_range
      tools/pitchtools/list_ordered_named_pitch_pairs_from_expr_1_to_expr_2
      tools/pitchtools/list_pitch_numbers_in_expr
      tools/pitchtools/list_unordered_named_pitch_pairs_in_expr
      tools/pitchtools/make_n_middle_c_centered_pitches
      tools/pitchtools/named_pitch_and_clef_to_staff_position_number
      tools/pitchtools/numbered_inversion_equivalent_interval_class_dictionary
      tools/pitchtools/permute_named_pitch_carrier_list_by_twelve_tone_row
      tools/pitchtools/register_pitch_class_numbers_by_pitch_number_aggregate
      tools/pitchtools/set_written_pitch_of_pitched_components_in_expr
      tools/pitchtools/sort_named_pitch_carriers_in_expr
      tools/pitchtools/spell_numbered_interval_number
      tools/pitchtools/spell_pitch_number
      tools/pitchtools/suggest_clef_for_named_pitches
      tools/pitchtools/transpose_named_pitch_by_numbered_interval_and_respell
      tools/pitchtools/transpose_pitch_carrier_by_interval
      tools/pitchtools/transpose_pitch_class_number_to_pitch_number_neighbor
      tools/pitchtools/transpose_pitch_expr_into_pitch_range
      tools/pitchtools/transpose_pitch_number_by_octave_transposition_mapping

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/pitchtools/Interval/Interval
      tools/pitchtools/IntervalClass/IntervalClass
      tools/pitchtools/Pitch/Pitch
      tools/pitchtools/PitchClass/PitchClass
      tools/pitchtools/Segment/Segment
      tools/pitchtools/Set/Set
      tools/pitchtools/Vector/Vector

   Concrete classes
   ----------------

   .. toctree::

      tools/pitchtools/Accidental/Accidental
      tools/pitchtools/IntervalClassSegment/IntervalClassSegment
      tools/pitchtools/IntervalClassSet/IntervalClassSet
      tools/pitchtools/IntervalClassVector/IntervalClassVector
      tools/pitchtools/IntervalSegment/IntervalSegment
      tools/pitchtools/IntervalSet/IntervalSet
      tools/pitchtools/IntervalVector/IntervalVector
      tools/pitchtools/NamedInterval/NamedInterval
      tools/pitchtools/NamedIntervalClass/NamedIntervalClass
      tools/pitchtools/NamedInversionEquivalentIntervalClass/NamedInversionEquivalentIntervalClass
      tools/pitchtools/NamedPitch/NamedPitch
      tools/pitchtools/NamedPitchClass/NamedPitchClass
      tools/pitchtools/NumberedInterval/NumberedInterval
      tools/pitchtools/NumberedIntervalClass/NumberedIntervalClass
      tools/pitchtools/NumberedInversionEquivalentIntervalClass/NumberedInversionEquivalentIntervalClass
      tools/pitchtools/NumberedPitch/NumberedPitch
      tools/pitchtools/NumberedPitchClass/NumberedPitchClass
      tools/pitchtools/NumberedPitchClassColorMap/NumberedPitchClassColorMap
      tools/pitchtools/Octave/Octave
      tools/pitchtools/OctaveTranspositionMapping/OctaveTranspositionMapping
      tools/pitchtools/OctaveTranspositionMappingComponent/OctaveTranspositionMappingComponent
      tools/pitchtools/OctaveTranspositionMappingInventory/OctaveTranspositionMappingInventory
      tools/pitchtools/PitchClassSegment/PitchClassSegment
      tools/pitchtools/PitchClassSet/PitchClassSet
      tools/pitchtools/PitchClassVector/PitchClassVector
      tools/pitchtools/PitchRange/PitchRange
      tools/pitchtools/PitchRangeInventory/PitchRangeInventory
      tools/pitchtools/PitchSegment/PitchSegment
      tools/pitchtools/PitchSet/PitchSet
      tools/pitchtools/PitchVector/PitchVector
      tools/pitchtools/TwelveToneRow/TwelveToneRow

   Functions
   ---------

   .. toctree::

      tools/pitchtools/apply_accidental_to_named_pitch
      tools/pitchtools/clef_and_staff_position_number_to_named_pitch
      tools/pitchtools/contains_subsegment
      tools/pitchtools/get_named_pitch_from_pitch_carrier
      tools/pitchtools/get_numbered_pitch_class_from_pitch_carrier
      tools/pitchtools/insert_and_transpose_nested_subruns_in_pitch_class_number_list
      tools/pitchtools/instantiate_pitch_and_interval_test_collection
      tools/pitchtools/inventory_aggregate_subsets
      tools/pitchtools/iterate_named_pitch_pairs_in_expr
      tools/pitchtools/list_named_pitches_in_expr
      tools/pitchtools/list_numbered_interval_numbers_pairwise
      tools/pitchtools/list_numbered_inversion_equivalent_interval_classes_pairwise
      tools/pitchtools/list_octave_transpositions_of_pitch_carrier_within_pitch_range
      tools/pitchtools/list_ordered_named_pitch_pairs_from_expr_1_to_expr_2
      tools/pitchtools/list_pitch_numbers_in_expr
      tools/pitchtools/list_unordered_named_pitch_pairs_in_expr
      tools/pitchtools/make_n_middle_c_centered_pitches
      tools/pitchtools/named_pitch_and_clef_to_staff_position_number
      tools/pitchtools/numbered_inversion_equivalent_interval_class_dictionary
      tools/pitchtools/permute_named_pitch_carrier_list_by_twelve_tone_row
      tools/pitchtools/register_pitch_class_numbers_by_pitch_number_aggregate
      tools/pitchtools/set_written_pitch_of_pitched_components_in_expr
      tools/pitchtools/sort_named_pitch_carriers_in_expr
      tools/pitchtools/spell_numbered_interval_number
      tools/pitchtools/spell_pitch_number
      tools/pitchtools/suggest_clef_for_named_pitches
      tools/pitchtools/transpose_named_pitch_by_numbered_interval_and_respell
      tools/pitchtools/transpose_pitch_carrier_by_interval
      tools/pitchtools/transpose_pitch_class_number_to_pitch_number_neighbor
      tools/pitchtools/transpose_pitch_expr_into_pitch_range
      tools/pitchtools/transpose_pitch_number_by_octave_transposition_mapping

:py:mod:`quantizationtools <abjad.tools.quantizationtools>`
===========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/quantizationtools/index

   .. toctree::
      :maxdepth: 1

      tools/quantizationtools/AttackPointOptimizer/AttackPointOptimizer
      tools/quantizationtools/GraceHandler/GraceHandler
      tools/quantizationtools/Heuristic/Heuristic
      tools/quantizationtools/JobHandler/JobHandler
      tools/quantizationtools/QEvent/QEvent
      tools/quantizationtools/QSchema/QSchema
      tools/quantizationtools/QSchemaItem/QSchemaItem
      tools/quantizationtools/QTarget/QTarget
      tools/quantizationtools/SearchTree/SearchTree

   .. toctree::
      :maxdepth: 1

      tools/quantizationtools/BeatwiseQSchema/BeatwiseQSchema
      tools/quantizationtools/BeatwiseQSchemaItem/BeatwiseQSchemaItem
      tools/quantizationtools/BeatwiseQTarget/BeatwiseQTarget
      tools/quantizationtools/CollapsingGraceHandler/CollapsingGraceHandler
      tools/quantizationtools/ConcatenatingGraceHandler/ConcatenatingGraceHandler
      tools/quantizationtools/DiscardingGraceHandler/DiscardingGraceHandler
      tools/quantizationtools/DistanceHeuristic/DistanceHeuristic
      tools/quantizationtools/MeasurewiseAttackPointOptimizer/MeasurewiseAttackPointOptimizer
      tools/quantizationtools/MeasurewiseQSchema/MeasurewiseQSchema
      tools/quantizationtools/MeasurewiseQSchemaItem/MeasurewiseQSchemaItem
      tools/quantizationtools/MeasurewiseQTarget/MeasurewiseQTarget
      tools/quantizationtools/NaiveAttackPointOptimizer/NaiveAttackPointOptimizer
      tools/quantizationtools/NullAttackPointOptimizer/NullAttackPointOptimizer
      tools/quantizationtools/ParallelJobHandler/ParallelJobHandler
      tools/quantizationtools/ParallelJobHandlerWorker/ParallelJobHandlerWorker
      tools/quantizationtools/PitchedQEvent/PitchedQEvent
      tools/quantizationtools/QEventProxy/QEventProxy
      tools/quantizationtools/QEventSequence/QEventSequence
      tools/quantizationtools/QGrid/QGrid
      tools/quantizationtools/QGridContainer/QGridContainer
      tools/quantizationtools/QGridLeaf/QGridLeaf
      tools/quantizationtools/QTargetBeat/QTargetBeat
      tools/quantizationtools/QTargetMeasure/QTargetMeasure
      tools/quantizationtools/QuantizationJob/QuantizationJob
      tools/quantizationtools/Quantizer/Quantizer
      tools/quantizationtools/SerialJobHandler/SerialJobHandler
      tools/quantizationtools/SilentQEvent/SilentQEvent
      tools/quantizationtools/TerminalQEvent/TerminalQEvent
      tools/quantizationtools/UnweightedSearchTree/UnweightedSearchTree
      tools/quantizationtools/WeightedSearchTree/WeightedSearchTree

   .. toctree::
      :maxdepth: 1

      tools/quantizationtools/make_test_time_segments

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/quantizationtools/AttackPointOptimizer/AttackPointOptimizer
      tools/quantizationtools/GraceHandler/GraceHandler
      tools/quantizationtools/Heuristic/Heuristic
      tools/quantizationtools/JobHandler/JobHandler
      tools/quantizationtools/QEvent/QEvent
      tools/quantizationtools/QSchema/QSchema
      tools/quantizationtools/QSchemaItem/QSchemaItem
      tools/quantizationtools/QTarget/QTarget
      tools/quantizationtools/SearchTree/SearchTree

   Concrete classes
   ----------------

   .. toctree::

      tools/quantizationtools/BeatwiseQSchema/BeatwiseQSchema
      tools/quantizationtools/BeatwiseQSchemaItem/BeatwiseQSchemaItem
      tools/quantizationtools/BeatwiseQTarget/BeatwiseQTarget
      tools/quantizationtools/CollapsingGraceHandler/CollapsingGraceHandler
      tools/quantizationtools/ConcatenatingGraceHandler/ConcatenatingGraceHandler
      tools/quantizationtools/DiscardingGraceHandler/DiscardingGraceHandler
      tools/quantizationtools/DistanceHeuristic/DistanceHeuristic
      tools/quantizationtools/MeasurewiseAttackPointOptimizer/MeasurewiseAttackPointOptimizer
      tools/quantizationtools/MeasurewiseQSchema/MeasurewiseQSchema
      tools/quantizationtools/MeasurewiseQSchemaItem/MeasurewiseQSchemaItem
      tools/quantizationtools/MeasurewiseQTarget/MeasurewiseQTarget
      tools/quantizationtools/NaiveAttackPointOptimizer/NaiveAttackPointOptimizer
      tools/quantizationtools/NullAttackPointOptimizer/NullAttackPointOptimizer
      tools/quantizationtools/ParallelJobHandler/ParallelJobHandler
      tools/quantizationtools/ParallelJobHandlerWorker/ParallelJobHandlerWorker
      tools/quantizationtools/PitchedQEvent/PitchedQEvent
      tools/quantizationtools/QEventProxy/QEventProxy
      tools/quantizationtools/QEventSequence/QEventSequence
      tools/quantizationtools/QGrid/QGrid
      tools/quantizationtools/QGridContainer/QGridContainer
      tools/quantizationtools/QGridLeaf/QGridLeaf
      tools/quantizationtools/QTargetBeat/QTargetBeat
      tools/quantizationtools/QTargetMeasure/QTargetMeasure
      tools/quantizationtools/QuantizationJob/QuantizationJob
      tools/quantizationtools/Quantizer/Quantizer
      tools/quantizationtools/SerialJobHandler/SerialJobHandler
      tools/quantizationtools/SilentQEvent/SilentQEvent
      tools/quantizationtools/TerminalQEvent/TerminalQEvent
      tools/quantizationtools/UnweightedSearchTree/UnweightedSearchTree
      tools/quantizationtools/WeightedSearchTree/WeightedSearchTree

   Functions
   ---------

   .. toctree::

      tools/quantizationtools/make_test_time_segments

:py:mod:`resttools <abjad.tools.resttools>`
===========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/resttools/index

   .. toctree::
      :maxdepth: 1

      tools/resttools/MultimeasureRest/MultimeasureRest
      tools/resttools/Rest/Rest

   .. toctree::
      :maxdepth: 1

      tools/resttools/make_multimeasure_rests
      tools/resttools/make_repeated_rests_from_time_signatures
      tools/resttools/make_rests

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/resttools/MultimeasureRest/MultimeasureRest
      tools/resttools/Rest/Rest

   Functions
   ---------

   .. toctree::

      tools/resttools/make_multimeasure_rests
      tools/resttools/make_repeated_rests_from_time_signatures
      tools/resttools/make_rests

:py:mod:`rhythmmakertools <abjad.tools.rhythmmakertools>`
=========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/rhythmmakertools/index

   .. toctree::
      :maxdepth: 1

      tools/rhythmmakertools/BurnishedRhythmMaker/BurnishedRhythmMaker
      tools/rhythmmakertools/DivisionIncisedRhythmMaker/DivisionIncisedRhythmMaker
      tools/rhythmmakertools/IncisedRhythmMaker/IncisedRhythmMaker
      tools/rhythmmakertools/OutputIncisedRhythmMaker/OutputIncisedRhythmMaker
      tools/rhythmmakertools/RhythmMaker/RhythmMaker

   .. toctree::
      :maxdepth: 1

      tools/rhythmmakertools/DivisionBurnishedTaleaRhythmMaker/DivisionBurnishedTaleaRhythmMaker
      tools/rhythmmakertools/DivisionIncisedNoteRhythmMaker/DivisionIncisedNoteRhythmMaker
      tools/rhythmmakertools/DivisionIncisedRestRhythmMaker/DivisionIncisedRestRhythmMaker
      tools/rhythmmakertools/EqualDivisionRhythmMaker/EqualDivisionRhythmMaker
      tools/rhythmmakertools/EvenRunRhythmMaker/EvenRunRhythmMaker
      tools/rhythmmakertools/NoteRhythmMaker/NoteRhythmMaker
      tools/rhythmmakertools/OutputBurnishedTaleaRhythmMaker/OutputBurnishedTaleaRhythmMaker
      tools/rhythmmakertools/OutputIncisedNoteRhythmMaker/OutputIncisedNoteRhythmMaker
      tools/rhythmmakertools/OutputIncisedRestRhythmMaker/OutputIncisedRestRhythmMaker
      tools/rhythmmakertools/RestRhythmMaker/RestRhythmMaker
      tools/rhythmmakertools/SkipRhythmMaker/SkipRhythmMaker
      tools/rhythmmakertools/TaleaRhythmMaker/TaleaRhythmMaker
      tools/rhythmmakertools/TupletMonadRhythmMaker/TupletMonadRhythmMaker

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/rhythmmakertools/BurnishedRhythmMaker/BurnishedRhythmMaker
      tools/rhythmmakertools/DivisionIncisedRhythmMaker/DivisionIncisedRhythmMaker
      tools/rhythmmakertools/IncisedRhythmMaker/IncisedRhythmMaker
      tools/rhythmmakertools/OutputIncisedRhythmMaker/OutputIncisedRhythmMaker
      tools/rhythmmakertools/RhythmMaker/RhythmMaker

   Concrete classes
   ----------------

   .. toctree::

      tools/rhythmmakertools/DivisionBurnishedTaleaRhythmMaker/DivisionBurnishedTaleaRhythmMaker
      tools/rhythmmakertools/DivisionIncisedNoteRhythmMaker/DivisionIncisedNoteRhythmMaker
      tools/rhythmmakertools/DivisionIncisedRestRhythmMaker/DivisionIncisedRestRhythmMaker
      tools/rhythmmakertools/EqualDivisionRhythmMaker/EqualDivisionRhythmMaker
      tools/rhythmmakertools/EvenRunRhythmMaker/EvenRunRhythmMaker
      tools/rhythmmakertools/NoteRhythmMaker/NoteRhythmMaker
      tools/rhythmmakertools/OutputBurnishedTaleaRhythmMaker/OutputBurnishedTaleaRhythmMaker
      tools/rhythmmakertools/OutputIncisedNoteRhythmMaker/OutputIncisedNoteRhythmMaker
      tools/rhythmmakertools/OutputIncisedRestRhythmMaker/OutputIncisedRestRhythmMaker
      tools/rhythmmakertools/RestRhythmMaker/RestRhythmMaker
      tools/rhythmmakertools/SkipRhythmMaker/SkipRhythmMaker
      tools/rhythmmakertools/TaleaRhythmMaker/TaleaRhythmMaker
      tools/rhythmmakertools/TupletMonadRhythmMaker/TupletMonadRhythmMaker

:py:mod:`rhythmtreetools <abjad.tools.rhythmtreetools>`
=======================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/rhythmtreetools/index

   .. toctree::
      :maxdepth: 1

      tools/rhythmtreetools/RhythmTreeNode/RhythmTreeNode

   .. toctree::
      :maxdepth: 1

      tools/rhythmtreetools/RhythmTreeContainer/RhythmTreeContainer
      tools/rhythmtreetools/RhythmTreeLeaf/RhythmTreeLeaf
      tools/rhythmtreetools/RhythmTreeParser/RhythmTreeParser

   .. toctree::
      :maxdepth: 1

      tools/rhythmtreetools/parse_rtm_syntax

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/rhythmtreetools/RhythmTreeNode/RhythmTreeNode

   Concrete classes
   ----------------

   .. toctree::

      tools/rhythmtreetools/RhythmTreeContainer/RhythmTreeContainer
      tools/rhythmtreetools/RhythmTreeLeaf/RhythmTreeLeaf
      tools/rhythmtreetools/RhythmTreeParser/RhythmTreeParser

   Functions
   ---------

   .. toctree::

      tools/rhythmtreetools/parse_rtm_syntax

:py:mod:`schemetools <abjad.tools.schemetools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/schemetools/index

   .. toctree::
      :maxdepth: 1

      tools/schemetools/Scheme/Scheme
      tools/schemetools/SchemeAssociativeList/SchemeAssociativeList
      tools/schemetools/SchemeColor/SchemeColor
      tools/schemetools/SchemeMoment/SchemeMoment
      tools/schemetools/SchemePair/SchemePair
      tools/schemetools/SchemeVector/SchemeVector
      tools/schemetools/SchemeVectorConstant/SchemeVectorConstant

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/schemetools/Scheme/Scheme
      tools/schemetools/SchemeAssociativeList/SchemeAssociativeList
      tools/schemetools/SchemeColor/SchemeColor
      tools/schemetools/SchemeMoment/SchemeMoment
      tools/schemetools/SchemePair/SchemePair
      tools/schemetools/SchemeVector/SchemeVector
      tools/schemetools/SchemeVectorConstant/SchemeVectorConstant

:py:mod:`scoretemplatetools <abjad.tools.scoretemplatetools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/scoretemplatetools/index

   .. toctree::
      :maxdepth: 1

      tools/scoretemplatetools/GroupedRhythmicStavesScoreTemplate/GroupedRhythmicStavesScoreTemplate
      tools/scoretemplatetools/GroupedStavesScoreTemplate/GroupedStavesScoreTemplate
      tools/scoretemplatetools/StringOrchestraScoreTemplate/StringOrchestraScoreTemplate
      tools/scoretemplatetools/StringQuartetScoreTemplate/StringQuartetScoreTemplate
      tools/scoretemplatetools/TwoStaffPianoScoreTemplate/TwoStaffPianoScoreTemplate

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/scoretemplatetools/GroupedRhythmicStavesScoreTemplate/GroupedRhythmicStavesScoreTemplate
      tools/scoretemplatetools/GroupedStavesScoreTemplate/GroupedStavesScoreTemplate
      tools/scoretemplatetools/StringOrchestraScoreTemplate/StringOrchestraScoreTemplate
      tools/scoretemplatetools/StringQuartetScoreTemplate/StringQuartetScoreTemplate
      tools/scoretemplatetools/TwoStaffPianoScoreTemplate/TwoStaffPianoScoreTemplate

:py:mod:`scoretools <abjad.tools.scoretools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/scoretools/index

   .. toctree::
      :maxdepth: 1

      tools/scoretools/GrandStaff/GrandStaff
      tools/scoretools/InstrumentationSpecifier/InstrumentationSpecifier
      tools/scoretools/Performer/Performer
      tools/scoretools/PerformerInventory/PerformerInventory
      tools/scoretools/PianoStaff/PianoStaff
      tools/scoretools/Score/Score
      tools/scoretools/StaffGroup/StaffGroup

   .. toctree::
      :maxdepth: 1

      tools/scoretools/make_empty_piano_score
      tools/scoretools/make_piano_score_from_leaves
      tools/scoretools/make_piano_sketch_score_from_leaves

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/scoretools/GrandStaff/GrandStaff
      tools/scoretools/InstrumentationSpecifier/InstrumentationSpecifier
      tools/scoretools/Performer/Performer
      tools/scoretools/PerformerInventory/PerformerInventory
      tools/scoretools/PianoStaff/PianoStaff
      tools/scoretools/Score/Score
      tools/scoretools/StaffGroup/StaffGroup

   Functions
   ---------

   .. toctree::

      tools/scoretools/make_empty_piano_score
      tools/scoretools/make_piano_score_from_leaves
      tools/scoretools/make_piano_sketch_score_from_leaves

:py:mod:`selectiontools <abjad.tools.selectiontools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/selectiontools/index

   .. toctree::
      :maxdepth: 1

      tools/selectiontools/ContiguousSelection/ContiguousSelection
      tools/selectiontools/Descendants/Descendants
      tools/selectiontools/Lineage/Lineage
      tools/selectiontools/Parentage/Parentage
      tools/selectiontools/Selection/Selection
      tools/selectiontools/SelectionInventory/SelectionInventory
      tools/selectiontools/SimultaneousSelection/SimultaneousSelection
      tools/selectiontools/SliceSelection/SliceSelection
      tools/selectiontools/TieChain/TieChain
      tools/selectiontools/VerticalMoment/VerticalMoment

   .. toctree::
      :maxdepth: 1

      tools/selectiontools/select

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/selectiontools/ContiguousSelection/ContiguousSelection
      tools/selectiontools/Descendants/Descendants
      tools/selectiontools/Lineage/Lineage
      tools/selectiontools/Parentage/Parentage
      tools/selectiontools/Selection/Selection
      tools/selectiontools/SelectionInventory/SelectionInventory
      tools/selectiontools/SimultaneousSelection/SimultaneousSelection
      tools/selectiontools/SliceSelection/SliceSelection
      tools/selectiontools/TieChain/TieChain
      tools/selectiontools/VerticalMoment/VerticalMoment

   Functions
   ---------

   .. toctree::

      tools/selectiontools/select

:py:mod:`sequencetools <abjad.tools.sequencetools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/sequencetools/index

   .. toctree::
      :maxdepth: 1

      tools/sequencetools/all_are_assignable_integers
      tools/sequencetools/all_are_equal
      tools/sequencetools/all_are_integer_equivalent_exprs
      tools/sequencetools/all_are_integer_equivalent_numbers
      tools/sequencetools/all_are_nonnegative_integer_equivalent_numbers
      tools/sequencetools/all_are_nonnegative_integer_powers_of_two
      tools/sequencetools/all_are_nonnegative_integers
      tools/sequencetools/all_are_numbers
      tools/sequencetools/all_are_pairs
      tools/sequencetools/all_are_pairs_of_types
      tools/sequencetools/all_are_positive_integer_equivalent_numbers
      tools/sequencetools/all_are_positive_integers
      tools/sequencetools/all_are_unequal
      tools/sequencetools/count_length_two_runs_in_sequence
      tools/sequencetools/divide_sequence_elements_by_greatest_common_divisor
      tools/sequencetools/flatten_sequence
      tools/sequencetools/flatten_sequence_at_indices
      tools/sequencetools/get_indices_of_sequence_elements_equal_to_true
      tools/sequencetools/get_sequence_degree_of_rotational_symmetry
      tools/sequencetools/get_sequence_element_at_cyclic_index
      tools/sequencetools/get_sequence_elements_at_indices
      tools/sequencetools/get_sequence_elements_frequency_distribution
      tools/sequencetools/get_sequence_period_of_rotation
      tools/sequencetools/increase_sequence_elements_at_indices_by_addenda
      tools/sequencetools/increase_sequence_elements_cyclically_by_addenda
      tools/sequencetools/interlace_sequences
      tools/sequencetools/is_fraction_equivalent_pair
      tools/sequencetools/is_integer_equivalent_n_tuple
      tools/sequencetools/is_integer_equivalent_pair
      tools/sequencetools/is_integer_equivalent_singleton
      tools/sequencetools/is_integer_n_tuple
      tools/sequencetools/is_integer_pair
      tools/sequencetools/is_integer_singleton
      tools/sequencetools/is_monotonically_decreasing_sequence
      tools/sequencetools/is_monotonically_increasing_sequence
      tools/sequencetools/is_n_tuple
      tools/sequencetools/is_null_tuple
      tools/sequencetools/is_pair
      tools/sequencetools/is_permutation
      tools/sequencetools/is_repetition_free_sequence
      tools/sequencetools/is_restricted_growth_function
      tools/sequencetools/is_singleton
      tools/sequencetools/is_strictly_decreasing_sequence
      tools/sequencetools/is_strictly_increasing_sequence
      tools/sequencetools/iterate_sequence_cyclically
      tools/sequencetools/iterate_sequence_cyclically_from_start_to_stop
      tools/sequencetools/iterate_sequence_forward_and_backward_nonoverlapping
      tools/sequencetools/iterate_sequence_forward_and_backward_overlapping
      tools/sequencetools/iterate_sequence_nwise_cyclic
      tools/sequencetools/iterate_sequence_nwise_strict
      tools/sequencetools/iterate_sequence_nwise_wrapped
      tools/sequencetools/iterate_sequence_pairwise_cyclic
      tools/sequencetools/iterate_sequence_pairwise_strict
      tools/sequencetools/iterate_sequence_pairwise_wrapped
      tools/sequencetools/join_subsequences
      tools/sequencetools/join_subsequences_by_sign_of_subsequence_elements
      tools/sequencetools/map_sequence_elements_to_canonic_tuples
      tools/sequencetools/map_sequence_elements_to_numbered_sublists
      tools/sequencetools/merge_duration_sequences
      tools/sequencetools/negate_absolute_value_of_sequence_elements_at_indices
      tools/sequencetools/negate_absolute_value_of_sequence_elements_cyclically
      tools/sequencetools/negate_sequence_elements_at_indices
      tools/sequencetools/negate_sequence_elements_cyclically
      tools/sequencetools/overwrite_sequence_elements_at_indices
      tools/sequencetools/pair_duration_sequence_elements_with_input_pair_values
      tools/sequencetools/partition_sequence_by_backgrounded_weights
      tools/sequencetools/partition_sequence_by_counts
      tools/sequencetools/partition_sequence_by_ratio_of_lengths
      tools/sequencetools/partition_sequence_by_ratio_of_weights
      tools/sequencetools/partition_sequence_by_restricted_growth_function
      tools/sequencetools/partition_sequence_by_sign_of_elements
      tools/sequencetools/partition_sequence_by_value_of_elements
      tools/sequencetools/partition_sequence_by_weights_at_least
      tools/sequencetools/partition_sequence_by_weights_at_most
      tools/sequencetools/partition_sequence_by_weights_exactly
      tools/sequencetools/partition_sequence_extended_to_counts
      tools/sequencetools/permute_sequence
      tools/sequencetools/remove_sequence_elements_at_indices
      tools/sequencetools/remove_sequence_elements_at_indices_cyclically
      tools/sequencetools/remove_subsequence_of_weight_at_index
      tools/sequencetools/repeat_runs_in_sequence_to_count
      tools/sequencetools/repeat_sequence_elements_at_indices
      tools/sequencetools/repeat_sequence_elements_at_indices_cyclically
      tools/sequencetools/repeat_sequence_elements_n_times_each
      tools/sequencetools/repeat_sequence_n_times
      tools/sequencetools/repeat_sequence_to_length
      tools/sequencetools/repeat_sequence_to_weight_at_least
      tools/sequencetools/repeat_sequence_to_weight_at_most
      tools/sequencetools/repeat_sequence_to_weight_exactly
      tools/sequencetools/replace_sequence_elements_cyclically_with_new_material
      tools/sequencetools/retain_sequence_elements_at_indices
      tools/sequencetools/retain_sequence_elements_at_indices_cyclically
      tools/sequencetools/reverse_sequence
      tools/sequencetools/reverse_sequence_elements
      tools/sequencetools/rotate_sequence
      tools/sequencetools/splice_new_elements_between_sequence_elements
      tools/sequencetools/split_sequence_by_weights
      tools/sequencetools/split_sequence_extended_to_weights
      tools/sequencetools/sum_consecutive_sequence_elements_by_sign
      tools/sequencetools/sum_sequence_elements_at_indices
      tools/sequencetools/truncate_runs_in_sequence
      tools/sequencetools/truncate_sequence_to_sum
      tools/sequencetools/truncate_sequence_to_weight
      tools/sequencetools/yield_all_combinations_of_sequence_elements
      tools/sequencetools/yield_all_k_ary_sequences_of_length
      tools/sequencetools/yield_all_pairs_between_sequences
      tools/sequencetools/yield_all_partitions_of_sequence
      tools/sequencetools/yield_all_permutations_of_sequence
      tools/sequencetools/yield_all_permutations_of_sequence_in_orbit
      tools/sequencetools/yield_all_restricted_growth_functions_of_length
      tools/sequencetools/yield_all_rotations_of_sequence
      tools/sequencetools/yield_all_set_partitions_of_sequence
      tools/sequencetools/yield_all_subsequences_of_sequence
      tools/sequencetools/yield_all_unordered_pairs_of_sequence
      tools/sequencetools/yield_outer_product_of_sequences
      tools/sequencetools/zip_sequences_cyclically
      tools/sequencetools/zip_sequences_without_truncation

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/sequencetools/all_are_assignable_integers
      tools/sequencetools/all_are_equal
      tools/sequencetools/all_are_integer_equivalent_exprs
      tools/sequencetools/all_are_integer_equivalent_numbers
      tools/sequencetools/all_are_nonnegative_integer_equivalent_numbers
      tools/sequencetools/all_are_nonnegative_integer_powers_of_two
      tools/sequencetools/all_are_nonnegative_integers
      tools/sequencetools/all_are_numbers
      tools/sequencetools/all_are_pairs
      tools/sequencetools/all_are_pairs_of_types
      tools/sequencetools/all_are_positive_integer_equivalent_numbers
      tools/sequencetools/all_are_positive_integers
      tools/sequencetools/all_are_unequal
      tools/sequencetools/count_length_two_runs_in_sequence
      tools/sequencetools/divide_sequence_elements_by_greatest_common_divisor
      tools/sequencetools/flatten_sequence
      tools/sequencetools/flatten_sequence_at_indices
      tools/sequencetools/get_indices_of_sequence_elements_equal_to_true
      tools/sequencetools/get_sequence_degree_of_rotational_symmetry
      tools/sequencetools/get_sequence_element_at_cyclic_index
      tools/sequencetools/get_sequence_elements_at_indices
      tools/sequencetools/get_sequence_elements_frequency_distribution
      tools/sequencetools/get_sequence_period_of_rotation
      tools/sequencetools/increase_sequence_elements_at_indices_by_addenda
      tools/sequencetools/increase_sequence_elements_cyclically_by_addenda
      tools/sequencetools/interlace_sequences
      tools/sequencetools/is_fraction_equivalent_pair
      tools/sequencetools/is_integer_equivalent_n_tuple
      tools/sequencetools/is_integer_equivalent_pair
      tools/sequencetools/is_integer_equivalent_singleton
      tools/sequencetools/is_integer_n_tuple
      tools/sequencetools/is_integer_pair
      tools/sequencetools/is_integer_singleton
      tools/sequencetools/is_monotonically_decreasing_sequence
      tools/sequencetools/is_monotonically_increasing_sequence
      tools/sequencetools/is_n_tuple
      tools/sequencetools/is_null_tuple
      tools/sequencetools/is_pair
      tools/sequencetools/is_permutation
      tools/sequencetools/is_repetition_free_sequence
      tools/sequencetools/is_restricted_growth_function
      tools/sequencetools/is_singleton
      tools/sequencetools/is_strictly_decreasing_sequence
      tools/sequencetools/is_strictly_increasing_sequence
      tools/sequencetools/iterate_sequence_cyclically
      tools/sequencetools/iterate_sequence_cyclically_from_start_to_stop
      tools/sequencetools/iterate_sequence_forward_and_backward_nonoverlapping
      tools/sequencetools/iterate_sequence_forward_and_backward_overlapping
      tools/sequencetools/iterate_sequence_nwise_cyclic
      tools/sequencetools/iterate_sequence_nwise_strict
      tools/sequencetools/iterate_sequence_nwise_wrapped
      tools/sequencetools/iterate_sequence_pairwise_cyclic
      tools/sequencetools/iterate_sequence_pairwise_strict
      tools/sequencetools/iterate_sequence_pairwise_wrapped
      tools/sequencetools/join_subsequences
      tools/sequencetools/join_subsequences_by_sign_of_subsequence_elements
      tools/sequencetools/map_sequence_elements_to_canonic_tuples
      tools/sequencetools/map_sequence_elements_to_numbered_sublists
      tools/sequencetools/merge_duration_sequences
      tools/sequencetools/negate_absolute_value_of_sequence_elements_at_indices
      tools/sequencetools/negate_absolute_value_of_sequence_elements_cyclically
      tools/sequencetools/negate_sequence_elements_at_indices
      tools/sequencetools/negate_sequence_elements_cyclically
      tools/sequencetools/overwrite_sequence_elements_at_indices
      tools/sequencetools/pair_duration_sequence_elements_with_input_pair_values
      tools/sequencetools/partition_sequence_by_backgrounded_weights
      tools/sequencetools/partition_sequence_by_counts
      tools/sequencetools/partition_sequence_by_ratio_of_lengths
      tools/sequencetools/partition_sequence_by_ratio_of_weights
      tools/sequencetools/partition_sequence_by_restricted_growth_function
      tools/sequencetools/partition_sequence_by_sign_of_elements
      tools/sequencetools/partition_sequence_by_value_of_elements
      tools/sequencetools/partition_sequence_by_weights_at_least
      tools/sequencetools/partition_sequence_by_weights_at_most
      tools/sequencetools/partition_sequence_by_weights_exactly
      tools/sequencetools/partition_sequence_extended_to_counts
      tools/sequencetools/permute_sequence
      tools/sequencetools/remove_sequence_elements_at_indices
      tools/sequencetools/remove_sequence_elements_at_indices_cyclically
      tools/sequencetools/remove_subsequence_of_weight_at_index
      tools/sequencetools/repeat_runs_in_sequence_to_count
      tools/sequencetools/repeat_sequence_elements_at_indices
      tools/sequencetools/repeat_sequence_elements_at_indices_cyclically
      tools/sequencetools/repeat_sequence_elements_n_times_each
      tools/sequencetools/repeat_sequence_n_times
      tools/sequencetools/repeat_sequence_to_length
      tools/sequencetools/repeat_sequence_to_weight_at_least
      tools/sequencetools/repeat_sequence_to_weight_at_most
      tools/sequencetools/repeat_sequence_to_weight_exactly
      tools/sequencetools/replace_sequence_elements_cyclically_with_new_material
      tools/sequencetools/retain_sequence_elements_at_indices
      tools/sequencetools/retain_sequence_elements_at_indices_cyclically
      tools/sequencetools/reverse_sequence
      tools/sequencetools/reverse_sequence_elements
      tools/sequencetools/rotate_sequence
      tools/sequencetools/splice_new_elements_between_sequence_elements
      tools/sequencetools/split_sequence_by_weights
      tools/sequencetools/split_sequence_extended_to_weights
      tools/sequencetools/sum_consecutive_sequence_elements_by_sign
      tools/sequencetools/sum_sequence_elements_at_indices
      tools/sequencetools/truncate_runs_in_sequence
      tools/sequencetools/truncate_sequence_to_sum
      tools/sequencetools/truncate_sequence_to_weight
      tools/sequencetools/yield_all_combinations_of_sequence_elements
      tools/sequencetools/yield_all_k_ary_sequences_of_length
      tools/sequencetools/yield_all_pairs_between_sequences
      tools/sequencetools/yield_all_partitions_of_sequence
      tools/sequencetools/yield_all_permutations_of_sequence
      tools/sequencetools/yield_all_permutations_of_sequence_in_orbit
      tools/sequencetools/yield_all_restricted_growth_functions_of_length
      tools/sequencetools/yield_all_rotations_of_sequence
      tools/sequencetools/yield_all_set_partitions_of_sequence
      tools/sequencetools/yield_all_subsequences_of_sequence
      tools/sequencetools/yield_all_unordered_pairs_of_sequence
      tools/sequencetools/yield_outer_product_of_sequences
      tools/sequencetools/zip_sequences_cyclically
      tools/sequencetools/zip_sequences_without_truncation

:py:mod:`sievetools <abjad.tools.sievetools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/sievetools/index

   .. toctree::
      :maxdepth: 1

      tools/sievetools/BaseResidueClass/BaseResidueClass
      tools/sievetools/ResidueClass/ResidueClass
      tools/sievetools/Sieve/Sieve

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/sievetools/BaseResidueClass/BaseResidueClass
      tools/sievetools/ResidueClass/ResidueClass
      tools/sievetools/Sieve/Sieve

:py:mod:`skiptools <abjad.tools.skiptools>`
===========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/skiptools/index

   .. toctree::
      :maxdepth: 1

      tools/skiptools/Skip/Skip

   .. toctree::
      :maxdepth: 1

      tools/skiptools/make_repeated_skips_from_time_signatures
      tools/skiptools/make_skips_with_multiplied_durations

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/skiptools/Skip/Skip

   Functions
   ---------

   .. toctree::

      tools/skiptools/make_repeated_skips_from_time_signatures
      tools/skiptools/make_skips_with_multiplied_durations

:py:mod:`spannertools <abjad.tools.spannertools>`
=================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/spannertools/index

   .. toctree::
      :maxdepth: 1

      tools/spannertools/DirectedSpanner/DirectedSpanner
      tools/spannertools/Spanner/Spanner

   .. toctree::
      :maxdepth: 1

      tools/spannertools/BeamSpanner/BeamSpanner
      tools/spannertools/BracketSpanner/BracketSpanner
      tools/spannertools/ComplexBeamSpanner/ComplexBeamSpanner
      tools/spannertools/ComplexGlissandoSpanner/ComplexGlissandoSpanner
      tools/spannertools/CrescendoSpanner/CrescendoSpanner
      tools/spannertools/DecrescendoSpanner/DecrescendoSpanner
      tools/spannertools/DuratedComplexBeamSpanner/DuratedComplexBeamSpanner
      tools/spannertools/DynamicTextSpanner/DynamicTextSpanner
      tools/spannertools/GlissandoSpanner/GlissandoSpanner
      tools/spannertools/HairpinSpanner/HairpinSpanner
      tools/spannertools/HiddenStaffSpanner/HiddenStaffSpanner
      tools/spannertools/HorizontalBracketSpanner/HorizontalBracketSpanner
      tools/spannertools/MeasuredComplexBeamSpanner/MeasuredComplexBeamSpanner
      tools/spannertools/MultipartBeamSpanner/MultipartBeamSpanner
      tools/spannertools/OctavationSpanner/OctavationSpanner
      tools/spannertools/PhrasingSlurSpanner/PhrasingSlurSpanner
      tools/spannertools/PianoPedalSpanner/PianoPedalSpanner
      tools/spannertools/SlurSpanner/SlurSpanner
      tools/spannertools/StaffLinesSpanner/StaffLinesSpanner
      tools/spannertools/TextScriptSpanner/TextScriptSpanner
      tools/spannertools/TextSpanner/TextSpanner
      tools/spannertools/TieSpanner/TieSpanner
      tools/spannertools/TrillSpanner/TrillSpanner

   .. toctree::
      :maxdepth: 1

      tools/spannertools/make_dynamic_spanner_below_with_nib_at_right
      tools/spannertools/make_solid_text_spanner_with_nib

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/spannertools/DirectedSpanner/DirectedSpanner
      tools/spannertools/Spanner/Spanner

   Concrete classes
   ----------------

   .. toctree::

      tools/spannertools/BeamSpanner/BeamSpanner
      tools/spannertools/BracketSpanner/BracketSpanner
      tools/spannertools/ComplexBeamSpanner/ComplexBeamSpanner
      tools/spannertools/ComplexGlissandoSpanner/ComplexGlissandoSpanner
      tools/spannertools/CrescendoSpanner/CrescendoSpanner
      tools/spannertools/DecrescendoSpanner/DecrescendoSpanner
      tools/spannertools/DuratedComplexBeamSpanner/DuratedComplexBeamSpanner
      tools/spannertools/DynamicTextSpanner/DynamicTextSpanner
      tools/spannertools/GlissandoSpanner/GlissandoSpanner
      tools/spannertools/HairpinSpanner/HairpinSpanner
      tools/spannertools/HiddenStaffSpanner/HiddenStaffSpanner
      tools/spannertools/HorizontalBracketSpanner/HorizontalBracketSpanner
      tools/spannertools/MeasuredComplexBeamSpanner/MeasuredComplexBeamSpanner
      tools/spannertools/MultipartBeamSpanner/MultipartBeamSpanner
      tools/spannertools/OctavationSpanner/OctavationSpanner
      tools/spannertools/PhrasingSlurSpanner/PhrasingSlurSpanner
      tools/spannertools/PianoPedalSpanner/PianoPedalSpanner
      tools/spannertools/SlurSpanner/SlurSpanner
      tools/spannertools/StaffLinesSpanner/StaffLinesSpanner
      tools/spannertools/TextScriptSpanner/TextScriptSpanner
      tools/spannertools/TextSpanner/TextSpanner
      tools/spannertools/TieSpanner/TieSpanner
      tools/spannertools/TrillSpanner/TrillSpanner

   Functions
   ---------

   .. toctree::

      tools/spannertools/make_dynamic_spanner_below_with_nib_at_right
      tools/spannertools/make_solid_text_spanner_with_nib

:py:mod:`stafftools <abjad.tools.stafftools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/stafftools/index

   .. toctree::
      :maxdepth: 1

      tools/stafftools/RhythmicStaff/RhythmicStaff
      tools/stafftools/Staff/Staff

   .. toctree::
      :maxdepth: 1

      tools/stafftools/make_rhythmic_sketch_staff

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/stafftools/RhythmicStaff/RhythmicStaff
      tools/stafftools/Staff/Staff

   Functions
   ---------

   .. toctree::

      tools/stafftools/make_rhythmic_sketch_staff

:py:mod:`stringtools <abjad.tools.stringtools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/stringtools/index

   .. toctree::
      :maxdepth: 1

      tools/stringtools/add_terminal_newlines
      tools/stringtools/arg_to_bidirectional_direction_string
      tools/stringtools/arg_to_bidirectional_lilypond_symbol
      tools/stringtools/arg_to_tridirectional_direction_string
      tools/stringtools/arg_to_tridirectional_lilypond_symbol
      tools/stringtools/arg_to_tridirectional_ordinal_constant
      tools/stringtools/capitalize_string_start
      tools/stringtools/format_input_lines_as_doc_string
      tools/stringtools/format_input_lines_as_regression_test
      tools/stringtools/is_dash_case_file_name
      tools/stringtools/is_dash_case_string
      tools/stringtools/is_lower_camel_case_string
      tools/stringtools/is_snake_case_file_name
      tools/stringtools/is_snake_case_file_name_with_extension
      tools/stringtools/is_snake_case_package_name
      tools/stringtools/is_snake_case_string
      tools/stringtools/is_space_delimited_lowercase_string
      tools/stringtools/is_upper_camel_case_string
      tools/stringtools/pluralize_string
      tools/stringtools/snake_case_to_lower_camel_case
      tools/stringtools/snake_case_to_upper_camel_case
      tools/stringtools/space_delimited_lowercase_to_upper_camel_case
      tools/stringtools/string_to_accent_free_snake_case
      tools/stringtools/string_to_space_delimited_lowercase
      tools/stringtools/strip_diacritics_from_binary_string
      tools/stringtools/upper_camel_case_to_snake_case
      tools/stringtools/upper_camel_case_to_space_delimited_lowercase

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/stringtools/add_terminal_newlines
      tools/stringtools/arg_to_bidirectional_direction_string
      tools/stringtools/arg_to_bidirectional_lilypond_symbol
      tools/stringtools/arg_to_tridirectional_direction_string
      tools/stringtools/arg_to_tridirectional_lilypond_symbol
      tools/stringtools/arg_to_tridirectional_ordinal_constant
      tools/stringtools/capitalize_string_start
      tools/stringtools/format_input_lines_as_doc_string
      tools/stringtools/format_input_lines_as_regression_test
      tools/stringtools/is_dash_case_file_name
      tools/stringtools/is_dash_case_string
      tools/stringtools/is_lower_camel_case_string
      tools/stringtools/is_snake_case_file_name
      tools/stringtools/is_snake_case_file_name_with_extension
      tools/stringtools/is_snake_case_package_name
      tools/stringtools/is_snake_case_string
      tools/stringtools/is_space_delimited_lowercase_string
      tools/stringtools/is_upper_camel_case_string
      tools/stringtools/pluralize_string
      tools/stringtools/snake_case_to_lower_camel_case
      tools/stringtools/snake_case_to_upper_camel_case
      tools/stringtools/space_delimited_lowercase_to_upper_camel_case
      tools/stringtools/string_to_accent_free_snake_case
      tools/stringtools/string_to_space_delimited_lowercase
      tools/stringtools/strip_diacritics_from_binary_string
      tools/stringtools/upper_camel_case_to_snake_case
      tools/stringtools/upper_camel_case_to_space_delimited_lowercase

:py:mod:`tempotools <abjad.tools.tempotools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/tempotools/index

   .. toctree::
      :maxdepth: 1

      tools/tempotools/report_integer_tempo_rewrite_pairs
      tools/tempotools/rewrite_duration_under_new_tempo
      tools/tempotools/rewrite_integer_tempo

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/tempotools/report_integer_tempo_rewrite_pairs
      tools/tempotools/rewrite_duration_under_new_tempo
      tools/tempotools/rewrite_integer_tempo

:py:mod:`timeintervaltools <abjad.tools.timeintervaltools>`
===========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/timeintervaltools/index

   .. toctree::
      :maxdepth: 1

      tools/timeintervaltools/TimeIntervalAggregateMixin/TimeIntervalAggregateMixin
      tools/timeintervaltools/TimeIntervalMixin/TimeIntervalMixin

   .. toctree::
      :maxdepth: 1

      tools/timeintervaltools/TimeInterval/TimeInterval
      tools/timeintervaltools/TimeIntervalTree/TimeIntervalTree
      tools/timeintervaltools/TimeIntervalTreeDictionary/TimeIntervalTreeDictionary
      tools/timeintervaltools/TimeIntervalTreeNode/TimeIntervalTreeNode

   .. toctree::
      :maxdepth: 1

      tools/timeintervaltools/concatenate_trees
      tools/timeintervaltools/make_test_intervals
      tools/timeintervaltools/mask_intervals_with_intervals
      tools/timeintervaltools/resolve_overlaps_between_nonoverlapping_trees

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/timeintervaltools/TimeIntervalAggregateMixin/TimeIntervalAggregateMixin
      tools/timeintervaltools/TimeIntervalMixin/TimeIntervalMixin

   Concrete classes
   ----------------

   .. toctree::

      tools/timeintervaltools/TimeInterval/TimeInterval
      tools/timeintervaltools/TimeIntervalTree/TimeIntervalTree
      tools/timeintervaltools/TimeIntervalTreeDictionary/TimeIntervalTreeDictionary
      tools/timeintervaltools/TimeIntervalTreeNode/TimeIntervalTreeNode

   Functions
   ---------

   .. toctree::

      tools/timeintervaltools/concatenate_trees
      tools/timeintervaltools/make_test_intervals
      tools/timeintervaltools/mask_intervals_with_intervals
      tools/timeintervaltools/resolve_overlaps_between_nonoverlapping_trees

:py:mod:`timerelationtools <abjad.tools.timerelationtools>`
===========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/timerelationtools/index

   .. toctree::
      :maxdepth: 1

      tools/timerelationtools/TimeRelation/TimeRelation

   .. toctree::
      :maxdepth: 1

      tools/timerelationtools/CompoundInequality/CompoundInequality
      tools/timerelationtools/OffsetTimespanTimeRelation/OffsetTimespanTimeRelation
      tools/timerelationtools/SimpleInequality/SimpleInequality
      tools/timerelationtools/TimespanTimespanTimeRelation/TimespanTimespanTimeRelation

   .. toctree::
      :maxdepth: 1

      tools/timerelationtools/offset_happens_after_timespan_starts
      tools/timerelationtools/offset_happens_after_timespan_stops
      tools/timerelationtools/offset_happens_before_timespan_starts
      tools/timerelationtools/offset_happens_before_timespan_stops
      tools/timerelationtools/offset_happens_during_timespan
      tools/timerelationtools/offset_happens_when_timespan_starts
      tools/timerelationtools/offset_happens_when_timespan_stops
      tools/timerelationtools/timespan_2_contains_timespan_1_improperly
      tools/timerelationtools/timespan_2_curtails_timespan_1
      tools/timerelationtools/timespan_2_delays_timespan_1
      tools/timerelationtools/timespan_2_happens_during_timespan_1
      tools/timerelationtools/timespan_2_intersects_timespan_1
      tools/timerelationtools/timespan_2_is_congruent_to_timespan_1
      tools/timerelationtools/timespan_2_overlaps_all_of_timespan_1
      tools/timerelationtools/timespan_2_overlaps_only_start_of_timespan_1
      tools/timerelationtools/timespan_2_overlaps_only_stop_of_timespan_1
      tools/timerelationtools/timespan_2_overlaps_start_of_timespan_1
      tools/timerelationtools/timespan_2_overlaps_stop_of_timespan_1
      tools/timerelationtools/timespan_2_starts_after_timespan_1_starts
      tools/timerelationtools/timespan_2_starts_after_timespan_1_stops
      tools/timerelationtools/timespan_2_starts_before_timespan_1_starts
      tools/timerelationtools/timespan_2_starts_before_timespan_1_stops
      tools/timerelationtools/timespan_2_starts_during_timespan_1
      tools/timerelationtools/timespan_2_starts_when_timespan_1_starts
      tools/timerelationtools/timespan_2_starts_when_timespan_1_stops
      tools/timerelationtools/timespan_2_stops_after_timespan_1_starts
      tools/timerelationtools/timespan_2_stops_after_timespan_1_stops
      tools/timerelationtools/timespan_2_stops_before_timespan_1_starts
      tools/timerelationtools/timespan_2_stops_before_timespan_1_stops
      tools/timerelationtools/timespan_2_stops_during_timespan_1
      tools/timerelationtools/timespan_2_stops_when_timespan_1_starts
      tools/timerelationtools/timespan_2_stops_when_timespan_1_stops
      tools/timerelationtools/timespan_2_trisects_timespan_1

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/timerelationtools/TimeRelation/TimeRelation

   Concrete classes
   ----------------

   .. toctree::

      tools/timerelationtools/CompoundInequality/CompoundInequality
      tools/timerelationtools/OffsetTimespanTimeRelation/OffsetTimespanTimeRelation
      tools/timerelationtools/SimpleInequality/SimpleInequality
      tools/timerelationtools/TimespanTimespanTimeRelation/TimespanTimespanTimeRelation

   Functions
   ---------

   .. toctree::

      tools/timerelationtools/offset_happens_after_timespan_starts
      tools/timerelationtools/offset_happens_after_timespan_stops
      tools/timerelationtools/offset_happens_before_timespan_starts
      tools/timerelationtools/offset_happens_before_timespan_stops
      tools/timerelationtools/offset_happens_during_timespan
      tools/timerelationtools/offset_happens_when_timespan_starts
      tools/timerelationtools/offset_happens_when_timespan_stops
      tools/timerelationtools/timespan_2_contains_timespan_1_improperly
      tools/timerelationtools/timespan_2_curtails_timespan_1
      tools/timerelationtools/timespan_2_delays_timespan_1
      tools/timerelationtools/timespan_2_happens_during_timespan_1
      tools/timerelationtools/timespan_2_intersects_timespan_1
      tools/timerelationtools/timespan_2_is_congruent_to_timespan_1
      tools/timerelationtools/timespan_2_overlaps_all_of_timespan_1
      tools/timerelationtools/timespan_2_overlaps_only_start_of_timespan_1
      tools/timerelationtools/timespan_2_overlaps_only_stop_of_timespan_1
      tools/timerelationtools/timespan_2_overlaps_start_of_timespan_1
      tools/timerelationtools/timespan_2_overlaps_stop_of_timespan_1
      tools/timerelationtools/timespan_2_starts_after_timespan_1_starts
      tools/timerelationtools/timespan_2_starts_after_timespan_1_stops
      tools/timerelationtools/timespan_2_starts_before_timespan_1_starts
      tools/timerelationtools/timespan_2_starts_before_timespan_1_stops
      tools/timerelationtools/timespan_2_starts_during_timespan_1
      tools/timerelationtools/timespan_2_starts_when_timespan_1_starts
      tools/timerelationtools/timespan_2_starts_when_timespan_1_stops
      tools/timerelationtools/timespan_2_stops_after_timespan_1_starts
      tools/timerelationtools/timespan_2_stops_after_timespan_1_stops
      tools/timerelationtools/timespan_2_stops_before_timespan_1_starts
      tools/timerelationtools/timespan_2_stops_before_timespan_1_stops
      tools/timerelationtools/timespan_2_stops_during_timespan_1
      tools/timerelationtools/timespan_2_stops_when_timespan_1_starts
      tools/timerelationtools/timespan_2_stops_when_timespan_1_stops
      tools/timerelationtools/timespan_2_trisects_timespan_1

:py:mod:`timesignaturetools <abjad.tools.timesignaturetools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/timesignaturetools/index

   .. toctree::
      :maxdepth: 1

      tools/timesignaturetools/MetricalHierarchy/MetricalHierarchy
      tools/timesignaturetools/MetricalHierarchyInventory/MetricalHierarchyInventory
      tools/timesignaturetools/MetricalKernel/MetricalKernel

   .. toctree::
      :maxdepth: 1

      tools/timesignaturetools/duration_and_possible_denominators_to_time_signature
      tools/timesignaturetools/establish_metrical_hierarchy
      tools/timesignaturetools/fit_metrical_hierarchies_to_expr
      tools/timesignaturetools/make_gridded_test_rhythm

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/timesignaturetools/MetricalHierarchy/MetricalHierarchy
      tools/timesignaturetools/MetricalHierarchyInventory/MetricalHierarchyInventory
      tools/timesignaturetools/MetricalKernel/MetricalKernel

   Functions
   ---------

   .. toctree::

      tools/timesignaturetools/duration_and_possible_denominators_to_time_signature
      tools/timesignaturetools/establish_metrical_hierarchy
      tools/timesignaturetools/fit_metrical_hierarchies_to_expr
      tools/timesignaturetools/make_gridded_test_rhythm

:py:mod:`timespantools <abjad.tools.timespantools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/timespantools/index

   .. toctree::
      :maxdepth: 1

      tools/timespantools/Timespan/Timespan
      tools/timespantools/TimespanInventory/TimespanInventory

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/timespantools/Timespan/Timespan
      tools/timespantools/TimespanInventory/TimespanInventory

:py:mod:`tonalanalysistools <abjad.tools.tonalanalysistools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/tonalanalysistools/index

   .. toctree::
      :maxdepth: 1

      tools/tonalanalysistools/ChordClass/ChordClass
      tools/tonalanalysistools/ChordQualityIndicator/ChordQualityIndicator
      tools/tonalanalysistools/ExtentIndicator/ExtentIndicator
      tools/tonalanalysistools/InversionIndicator/InversionIndicator
      tools/tonalanalysistools/Mode/Mode
      tools/tonalanalysistools/OmissionIndicator/OmissionIndicator
      tools/tonalanalysistools/QualityIndicator/QualityIndicator
      tools/tonalanalysistools/RomanNumeral/RomanNumeral
      tools/tonalanalysistools/Scale/Scale
      tools/tonalanalysistools/ScaleDegree/ScaleDegree
      tools/tonalanalysistools/SuspensionIndicator/SuspensionIndicator
      tools/tonalanalysistools/TonalAnalysisAgent/TonalAnalysisAgent

   .. toctree::
      :maxdepth: 1

      tools/tonalanalysistools/select

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/tonalanalysistools/ChordClass/ChordClass
      tools/tonalanalysistools/ChordQualityIndicator/ChordQualityIndicator
      tools/tonalanalysistools/ExtentIndicator/ExtentIndicator
      tools/tonalanalysistools/InversionIndicator/InversionIndicator
      tools/tonalanalysistools/Mode/Mode
      tools/tonalanalysistools/OmissionIndicator/OmissionIndicator
      tools/tonalanalysistools/QualityIndicator/QualityIndicator
      tools/tonalanalysistools/RomanNumeral/RomanNumeral
      tools/tonalanalysistools/Scale/Scale
      tools/tonalanalysistools/ScaleDegree/ScaleDegree
      tools/tonalanalysistools/SuspensionIndicator/SuspensionIndicator
      tools/tonalanalysistools/TonalAnalysisAgent/TonalAnalysisAgent

   Functions
   ---------

   .. toctree::

      tools/tonalanalysistools/select

:py:mod:`tuplettools <abjad.tools.tuplettools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/tuplettools/index

   .. toctree::
      :maxdepth: 1

      tools/tuplettools/FixedDurationTuplet/FixedDurationTuplet
      tools/tuplettools/Tuplet/Tuplet

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/tuplettools/FixedDurationTuplet/FixedDurationTuplet
      tools/tuplettools/Tuplet/Tuplet

:py:mod:`voicetools <abjad.tools.voicetools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/voicetools/index

   .. toctree::
      :maxdepth: 1

      tools/voicetools/Voice/Voice

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/voicetools/Voice/Voice

:py:mod:`wellformednesstools <abjad.tools.wellformednesstools>`
===============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/wellformednesstools/index

   .. toctree::
      :maxdepth: 1

      tools/wellformednesstools/Check/Check

   .. toctree::
      :maxdepth: 1

      tools/wellformednesstools/BeamedQuarterNoteCheck/BeamedQuarterNoteCheck
      tools/wellformednesstools/DiscontiguousSpannerCheck/DiscontiguousSpannerCheck
      tools/wellformednesstools/DuplicateIdCheck/DuplicateIdCheck
      tools/wellformednesstools/EmptyContainerCheck/EmptyContainerCheck
      tools/wellformednesstools/IntermarkedHairpinCheck/IntermarkedHairpinCheck
      tools/wellformednesstools/MisduratedMeasureCheck/MisduratedMeasureCheck
      tools/wellformednesstools/MisfilledMeasureCheck/MisfilledMeasureCheck
      tools/wellformednesstools/MispitchedTieCheck/MispitchedTieCheck
      tools/wellformednesstools/MisrepresentedFlagCheck/MisrepresentedFlagCheck
      tools/wellformednesstools/MissingParentCheck/MissingParentCheck
      tools/wellformednesstools/NestedMeasureCheck/NestedMeasureCheck
      tools/wellformednesstools/OverlappingBeamCheck/OverlappingBeamCheck
      tools/wellformednesstools/OverlappingGlissandoCheck/OverlappingGlissandoCheck
      tools/wellformednesstools/OverlappingOctavationCheck/OverlappingOctavationCheck
      tools/wellformednesstools/ShortHairpinCheck/ShortHairpinCheck

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/wellformednesstools/Check/Check

   Concrete classes
   ----------------

   .. toctree::

      tools/wellformednesstools/BeamedQuarterNoteCheck/BeamedQuarterNoteCheck
      tools/wellformednesstools/DiscontiguousSpannerCheck/DiscontiguousSpannerCheck
      tools/wellformednesstools/DuplicateIdCheck/DuplicateIdCheck
      tools/wellformednesstools/EmptyContainerCheck/EmptyContainerCheck
      tools/wellformednesstools/IntermarkedHairpinCheck/IntermarkedHairpinCheck
      tools/wellformednesstools/MisduratedMeasureCheck/MisduratedMeasureCheck
      tools/wellformednesstools/MisfilledMeasureCheck/MisfilledMeasureCheck
      tools/wellformednesstools/MispitchedTieCheck/MispitchedTieCheck
      tools/wellformednesstools/MisrepresentedFlagCheck/MisrepresentedFlagCheck
      tools/wellformednesstools/MissingParentCheck/MissingParentCheck
      tools/wellformednesstools/NestedMeasureCheck/NestedMeasureCheck
      tools/wellformednesstools/OverlappingBeamCheck/OverlappingBeamCheck
      tools/wellformednesstools/OverlappingGlissandoCheck/OverlappingGlissandoCheck
      tools/wellformednesstools/OverlappingOctavationCheck/OverlappingOctavationCheck
      tools/wellformednesstools/ShortHairpinCheck/ShortHairpinCheck

**************************
Demos and example packages
**************************

:py:mod:`desordre <abjad.demos.desordre>`
=========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      demos/desordre/index

   .. toctree::
      :maxdepth: 1

      demos/desordre/make_desordre_cell
      demos/desordre/make_desordre_lilypond_file
      demos/desordre/make_desordre_measure
      demos/desordre/make_desordre_pitches
      demos/desordre/make_desordre_score
      demos/desordre/make_desordre_staff

.. only:: latex

   Functions
   ---------

   .. toctree::

      demos/desordre/make_desordre_cell
      demos/desordre/make_desordre_lilypond_file
      demos/desordre/make_desordre_measure
      demos/desordre/make_desordre_pitches
      demos/desordre/make_desordre_score
      demos/desordre/make_desordre_staff

:py:mod:`ferneyhough <abjad.demos.ferneyhough>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      demos/ferneyhough/index

   .. toctree::
      :maxdepth: 1

      demos/ferneyhough/configure_lilypond_file
      demos/ferneyhough/configure_score
      demos/ferneyhough/make_lilypond_file
      demos/ferneyhough/make_nested_tuplet
      demos/ferneyhough/make_row_of_nested_tuplets
      demos/ferneyhough/make_rows_of_nested_tuplets
      demos/ferneyhough/make_score

.. only:: latex

   Functions
   ---------

   .. toctree::

      demos/ferneyhough/configure_lilypond_file
      demos/ferneyhough/configure_score
      demos/ferneyhough/make_lilypond_file
      demos/ferneyhough/make_nested_tuplet
      demos/ferneyhough/make_row_of_nested_tuplets
      demos/ferneyhough/make_rows_of_nested_tuplets
      demos/ferneyhough/make_score

:py:mod:`mozart <abjad.demos.mozart>`
=====================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      demos/mozart/index

   .. toctree::
      :maxdepth: 1

      demos/mozart/choose_mozart_measures
      demos/mozart/make_mozart_lilypond_file
      demos/mozart/make_mozart_measure
      demos/mozart/make_mozart_measure_corpus
      demos/mozart/make_mozart_score

.. only:: latex

   Functions
   ---------

   .. toctree::

      demos/mozart/choose_mozart_measures
      demos/mozart/make_mozart_lilypond_file
      demos/mozart/make_mozart_measure
      demos/mozart/make_mozart_measure_corpus
      demos/mozart/make_mozart_score

:py:mod:`part <abjad.demos.part>`
=================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      demos/part/index

   .. toctree::
      :maxdepth: 1

      demos/part/PartCantusScoreTemplate/PartCantusScoreTemplate

   .. toctree::
      :maxdepth: 1

      demos/part/add_bell_music_to_score
      demos/part/add_string_music_to_score
      demos/part/apply_bowing_marks
      demos/part/apply_dynamic_marks
      demos/part/apply_expressive_marks
      demos/part/apply_final_bar_lines
      demos/part/apply_page_breaks
      demos/part/apply_rehearsal_marks
      demos/part/configure_lilypond_file
      demos/part/configure_score
      demos/part/create_pitch_contour_reservoir
      demos/part/durate_pitch_contour_reservoir
      demos/part/edit_bass_voice
      demos/part/edit_cello_voice
      demos/part/edit_first_violin_voice
      demos/part/edit_second_violin_voice
      demos/part/edit_viola_voice
      demos/part/make_part_lilypond_file
      demos/part/shadow_pitch_contour_reservoir

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      demos/part/PartCantusScoreTemplate/PartCantusScoreTemplate

   Functions
   ---------

   .. toctree::

      demos/part/add_bell_music_to_score
      demos/part/add_string_music_to_score
      demos/part/apply_bowing_marks
      demos/part/apply_dynamic_marks
      demos/part/apply_expressive_marks
      demos/part/apply_final_bar_lines
      demos/part/apply_page_breaks
      demos/part/apply_rehearsal_marks
      demos/part/configure_lilypond_file
      demos/part/configure_score
      demos/part/create_pitch_contour_reservoir
      demos/part/durate_pitch_contour_reservoir
      demos/part/edit_bass_voice
      demos/part/edit_cello_voice
      demos/part/edit_first_violin_voice
      demos/part/edit_second_violin_voice
      demos/part/edit_viola_voice
      demos/part/make_part_lilypond_file
      demos/part/shadow_pitch_contour_reservoir

***********************
Abjad internal packages
***********************

:py:mod:`abctools <abjad.tools.abctools>`
=========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/abctools/index

   .. toctree::
      :maxdepth: 1

      tools/abctools/ContextManager/ContextManager
      tools/abctools/Maker/Maker
      tools/abctools/Parser/Parser

   .. toctree::
      :maxdepth: 1

      tools/abctools/AbjadObject/AbjadObject

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/abctools/ContextManager/ContextManager
      tools/abctools/Maker/Maker
      tools/abctools/Parser/Parser

   Concrete classes
   ----------------

   .. toctree::

      tools/abctools/AbjadObject/AbjadObject

:py:mod:`abjadbooktools <abjad.tools.abjadbooktools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/abjadbooktools/index

   .. toctree::
      :maxdepth: 1

      tools/abjadbooktools/OutputFormat/OutputFormat

   .. toctree::
      :maxdepth: 1

      tools/abjadbooktools/AbjadBookProcessor/AbjadBookProcessor
      tools/abjadbooktools/AbjadBookScript/AbjadBookScript
      tools/abjadbooktools/CodeBlock/CodeBlock
      tools/abjadbooktools/HTMLOutputFormat/HTMLOutputFormat
      tools/abjadbooktools/LaTeXOutputFormat/LaTeXOutputFormat
      tools/abjadbooktools/ReSTOutputFormat/ReSTOutputFormat

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/abjadbooktools/OutputFormat/OutputFormat

   Concrete classes
   ----------------

   .. toctree::

      tools/abjadbooktools/AbjadBookProcessor/AbjadBookProcessor
      tools/abjadbooktools/AbjadBookScript/AbjadBookScript
      tools/abjadbooktools/CodeBlock/CodeBlock
      tools/abjadbooktools/HTMLOutputFormat/HTMLOutputFormat
      tools/abjadbooktools/LaTeXOutputFormat/LaTeXOutputFormat
      tools/abjadbooktools/ReSTOutputFormat/ReSTOutputFormat

:py:mod:`configurationtools <abjad.tools.configurationtools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/configurationtools/index

   .. toctree::
      :maxdepth: 1

      tools/configurationtools/Configuration/Configuration

   .. toctree::
      :maxdepth: 1

      tools/configurationtools/AbjadConfiguration/AbjadConfiguration

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/configurationtools/Configuration/Configuration

   Concrete classes
   ----------------

   .. toctree::

      tools/configurationtools/AbjadConfiguration/AbjadConfiguration

:py:mod:`datastructuretools <abjad.tools.datastructuretools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/datastructuretools/index

   .. toctree::
      :maxdepth: 1

      tools/datastructuretools/TypedCollection/TypedCollection

   .. toctree::
      :maxdepth: 1

      tools/datastructuretools/BreakPointFunction/BreakPointFunction
      tools/datastructuretools/CyclicList/CyclicList
      tools/datastructuretools/CyclicMatrix/CyclicMatrix
      tools/datastructuretools/CyclicPayloadTree/CyclicPayloadTree
      tools/datastructuretools/CyclicTuple/CyclicTuple
      tools/datastructuretools/Matrix/Matrix
      tools/datastructuretools/OrdinalConstant/OrdinalConstant
      tools/datastructuretools/PayloadTree/PayloadTree
      tools/datastructuretools/SortedCollection/SortedCollection
      tools/datastructuretools/TreeContainer/TreeContainer
      tools/datastructuretools/TreeNode/TreeNode
      tools/datastructuretools/TypedCounter/TypedCounter
      tools/datastructuretools/TypedFrozenset/TypedFrozenset
      tools/datastructuretools/TypedList/TypedList
      tools/datastructuretools/TypedTuple/TypedTuple

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/datastructuretools/TypedCollection/TypedCollection

   Concrete classes
   ----------------

   .. toctree::

      tools/datastructuretools/BreakPointFunction/BreakPointFunction
      tools/datastructuretools/CyclicList/CyclicList
      tools/datastructuretools/CyclicMatrix/CyclicMatrix
      tools/datastructuretools/CyclicPayloadTree/CyclicPayloadTree
      tools/datastructuretools/CyclicTuple/CyclicTuple
      tools/datastructuretools/Matrix/Matrix
      tools/datastructuretools/OrdinalConstant/OrdinalConstant
      tools/datastructuretools/PayloadTree/PayloadTree
      tools/datastructuretools/SortedCollection/SortedCollection
      tools/datastructuretools/TreeContainer/TreeContainer
      tools/datastructuretools/TreeNode/TreeNode
      tools/datastructuretools/TypedCounter/TypedCounter
      tools/datastructuretools/TypedFrozenset/TypedFrozenset
      tools/datastructuretools/TypedList/TypedList
      tools/datastructuretools/TypedTuple/TypedTuple

:py:mod:`decoratortools <abjad.tools.decoratortools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/decoratortools/index

   .. toctree::
      :maxdepth: 1

      tools/decoratortools/requires

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/decoratortools/requires

:py:mod:`developerscripttools <abjad.tools.developerscripttools>`
=================================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/developerscripttools/index

   .. toctree::
      :maxdepth: 1

      tools/developerscripttools/DeveloperScript/DeveloperScript
      tools/developerscripttools/DirectoryScript/DirectoryScript

   .. toctree::
      :maxdepth: 1

      tools/developerscripttools/AbjDevScript/AbjDevScript
      tools/developerscripttools/AbjGrepScript/AbjGrepScript
      tools/developerscripttools/AbjUpScript/AbjUpScript
      tools/developerscripttools/BuildApiScript/BuildApiScript
      tools/developerscripttools/CleanScript/CleanScript
      tools/developerscripttools/CountLinewidthsScript/CountLinewidthsScript
      tools/developerscripttools/CountToolsScript/CountToolsScript
      tools/developerscripttools/MakeNewClassTemplateScript/MakeNewClassTemplateScript
      tools/developerscripttools/MakeNewFunctionTemplateScript/MakeNewFunctionTemplateScript
      tools/developerscripttools/PyTestScript/PyTestScript
      tools/developerscripttools/RenameModulesScript/RenameModulesScript
      tools/developerscripttools/ReplaceInFilesScript/ReplaceInFilesScript
      tools/developerscripttools/RunDoctestsScript/RunDoctestsScript
      tools/developerscripttools/SvnAddAllScript/SvnAddAllScript
      tools/developerscripttools/SvnCommitScript/SvnCommitScript
      tools/developerscripttools/SvnMessageScript/SvnMessageScript
      tools/developerscripttools/SvnUpdateScript/SvnUpdateScript
      tools/developerscripttools/TestAndRebuildScript/TestAndRebuildScript

   .. toctree::
      :maxdepth: 1

      tools/developerscripttools/get_developer_script_classes
      tools/developerscripttools/run_abjadbook
      tools/developerscripttools/run_abjdev

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/developerscripttools/DeveloperScript/DeveloperScript
      tools/developerscripttools/DirectoryScript/DirectoryScript

   Concrete classes
   ----------------

   .. toctree::

      tools/developerscripttools/AbjDevScript/AbjDevScript
      tools/developerscripttools/AbjGrepScript/AbjGrepScript
      tools/developerscripttools/AbjUpScript/AbjUpScript
      tools/developerscripttools/BuildApiScript/BuildApiScript
      tools/developerscripttools/CleanScript/CleanScript
      tools/developerscripttools/CountLinewidthsScript/CountLinewidthsScript
      tools/developerscripttools/CountToolsScript/CountToolsScript
      tools/developerscripttools/MakeNewClassTemplateScript/MakeNewClassTemplateScript
      tools/developerscripttools/MakeNewFunctionTemplateScript/MakeNewFunctionTemplateScript
      tools/developerscripttools/PyTestScript/PyTestScript
      tools/developerscripttools/RenameModulesScript/RenameModulesScript
      tools/developerscripttools/ReplaceInFilesScript/ReplaceInFilesScript
      tools/developerscripttools/RunDoctestsScript/RunDoctestsScript
      tools/developerscripttools/SvnAddAllScript/SvnAddAllScript
      tools/developerscripttools/SvnCommitScript/SvnCommitScript
      tools/developerscripttools/SvnMessageScript/SvnMessageScript
      tools/developerscripttools/SvnUpdateScript/SvnUpdateScript
      tools/developerscripttools/TestAndRebuildScript/TestAndRebuildScript

   Functions
   ---------

   .. toctree::

      tools/developerscripttools/get_developer_script_classes
      tools/developerscripttools/run_abjadbook
      tools/developerscripttools/run_abjdev

:py:mod:`documentationtools <abjad.tools.documentationtools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/documentationtools/index

   .. toctree::
      :maxdepth: 1

      tools/documentationtools/Documenter/Documenter
      tools/documentationtools/GraphvizObject/GraphvizObject
      tools/documentationtools/ReSTDirective/ReSTDirective

   .. toctree::
      :maxdepth: 1

      tools/documentationtools/AbjadAPIGenerator/AbjadAPIGenerator
      tools/documentationtools/ClassCrawler/ClassCrawler
      tools/documentationtools/ClassDocumenter/ClassDocumenter
      tools/documentationtools/FunctionCrawler/FunctionCrawler
      tools/documentationtools/FunctionDocumenter/FunctionDocumenter
      tools/documentationtools/GraphvizEdge/GraphvizEdge
      tools/documentationtools/GraphvizGraph/GraphvizGraph
      tools/documentationtools/GraphvizNode/GraphvizNode
      tools/documentationtools/GraphvizSubgraph/GraphvizSubgraph
      tools/documentationtools/InheritanceGraph/InheritanceGraph
      tools/documentationtools/ModuleCrawler/ModuleCrawler
      tools/documentationtools/Pipe/Pipe
      tools/documentationtools/ReSTAutodocDirective/ReSTAutodocDirective
      tools/documentationtools/ReSTAutosummaryDirective/ReSTAutosummaryDirective
      tools/documentationtools/ReSTAutosummaryItem/ReSTAutosummaryItem
      tools/documentationtools/ReSTDocument/ReSTDocument
      tools/documentationtools/ReSTHeading/ReSTHeading
      tools/documentationtools/ReSTHorizontalRule/ReSTHorizontalRule
      tools/documentationtools/ReSTInheritanceDiagram/ReSTInheritanceDiagram
      tools/documentationtools/ReSTLineageDirective/ReSTLineageDirective
      tools/documentationtools/ReSTOnlyDirective/ReSTOnlyDirective
      tools/documentationtools/ReSTParagraph/ReSTParagraph
      tools/documentationtools/ReSTTOCDirective/ReSTTOCDirective
      tools/documentationtools/ReSTTOCItem/ReSTTOCItem
      tools/documentationtools/ToolsPackageDocumenter/ToolsPackageDocumenter

   .. toctree::
      :maxdepth: 1

      tools/documentationtools/compare_images
      tools/documentationtools/make_ligeti_example_lilypond_file
      tools/documentationtools/make_reference_manual_graphviz_graph
      tools/documentationtools/make_reference_manual_lilypond_file
      tools/documentationtools/make_text_alignment_example_lilypond_file

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/documentationtools/Documenter/Documenter
      tools/documentationtools/GraphvizObject/GraphvizObject
      tools/documentationtools/ReSTDirective/ReSTDirective

   Concrete classes
   ----------------

   .. toctree::

      tools/documentationtools/AbjadAPIGenerator/AbjadAPIGenerator
      tools/documentationtools/ClassCrawler/ClassCrawler
      tools/documentationtools/ClassDocumenter/ClassDocumenter
      tools/documentationtools/FunctionCrawler/FunctionCrawler
      tools/documentationtools/FunctionDocumenter/FunctionDocumenter
      tools/documentationtools/GraphvizEdge/GraphvizEdge
      tools/documentationtools/GraphvizGraph/GraphvizGraph
      tools/documentationtools/GraphvizNode/GraphvizNode
      tools/documentationtools/GraphvizSubgraph/GraphvizSubgraph
      tools/documentationtools/InheritanceGraph/InheritanceGraph
      tools/documentationtools/ModuleCrawler/ModuleCrawler
      tools/documentationtools/Pipe/Pipe
      tools/documentationtools/ReSTAutodocDirective/ReSTAutodocDirective
      tools/documentationtools/ReSTAutosummaryDirective/ReSTAutosummaryDirective
      tools/documentationtools/ReSTAutosummaryItem/ReSTAutosummaryItem
      tools/documentationtools/ReSTDocument/ReSTDocument
      tools/documentationtools/ReSTHeading/ReSTHeading
      tools/documentationtools/ReSTHorizontalRule/ReSTHorizontalRule
      tools/documentationtools/ReSTInheritanceDiagram/ReSTInheritanceDiagram
      tools/documentationtools/ReSTLineageDirective/ReSTLineageDirective
      tools/documentationtools/ReSTOnlyDirective/ReSTOnlyDirective
      tools/documentationtools/ReSTParagraph/ReSTParagraph
      tools/documentationtools/ReSTTOCDirective/ReSTTOCDirective
      tools/documentationtools/ReSTTOCItem/ReSTTOCItem
      tools/documentationtools/ToolsPackageDocumenter/ToolsPackageDocumenter

   Functions
   ---------

   .. toctree::

      tools/documentationtools/compare_images
      tools/documentationtools/make_ligeti_example_lilypond_file
      tools/documentationtools/make_reference_manual_graphviz_graph
      tools/documentationtools/make_reference_manual_lilypond_file
      tools/documentationtools/make_text_alignment_example_lilypond_file

:py:mod:`exceptiontools <abjad.tools.exceptiontools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/exceptiontools/index

   .. toctree::
      :maxdepth: 1

      tools/exceptiontools/AssignabilityError
      tools/exceptiontools/ExtraMarkError
      tools/exceptiontools/ExtraNamedComponentError
      tools/exceptiontools/ExtraNoteHeadError
      tools/exceptiontools/ExtraPitchError
      tools/exceptiontools/ExtraSpannerError
      tools/exceptiontools/ImpreciseTempoError
      tools/exceptiontools/InstrumentError
      tools/exceptiontools/LilyPondParserError
      tools/exceptiontools/MissingInstrumentError
      tools/exceptiontools/MissingMarkError
      tools/exceptiontools/MissingMeasureError
      tools/exceptiontools/MissingNamedComponentError
      tools/exceptiontools/MissingNoteHeadError
      tools/exceptiontools/MissingPitchError
      tools/exceptiontools/MissingSpannerError
      tools/exceptiontools/MissingTempoError
      tools/exceptiontools/OverfullContainerError
      tools/exceptiontools/PartitionError
      tools/exceptiontools/SchemeParserFinishedException
      tools/exceptiontools/SpannerPopulationError
      tools/exceptiontools/TempoError
      tools/exceptiontools/TieChainError
      tools/exceptiontools/TimeSignatureError
      tools/exceptiontools/TonalHarmonyError
      tools/exceptiontools/TupletFuseError
      tools/exceptiontools/UnboundedTimeIntervalError
      tools/exceptiontools/UnderfullContainerError

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/exceptiontools/AssignabilityError
      tools/exceptiontools/ExtraMarkError
      tools/exceptiontools/ExtraNamedComponentError
      tools/exceptiontools/ExtraNoteHeadError
      tools/exceptiontools/ExtraPitchError
      tools/exceptiontools/ExtraSpannerError
      tools/exceptiontools/ImpreciseTempoError
      tools/exceptiontools/InstrumentError
      tools/exceptiontools/LilyPondParserError
      tools/exceptiontools/MissingInstrumentError
      tools/exceptiontools/MissingMarkError
      tools/exceptiontools/MissingMeasureError
      tools/exceptiontools/MissingNamedComponentError
      tools/exceptiontools/MissingNoteHeadError
      tools/exceptiontools/MissingPitchError
      tools/exceptiontools/MissingSpannerError
      tools/exceptiontools/MissingTempoError
      tools/exceptiontools/OverfullContainerError
      tools/exceptiontools/PartitionError
      tools/exceptiontools/SchemeParserFinishedException
      tools/exceptiontools/SpannerPopulationError
      tools/exceptiontools/TempoError
      tools/exceptiontools/TieChainError
      tools/exceptiontools/TimeSignatureError
      tools/exceptiontools/TonalHarmonyError
      tools/exceptiontools/TupletFuseError
      tools/exceptiontools/UnboundedTimeIntervalError
      tools/exceptiontools/UnderfullContainerError

:py:mod:`formattools <abjad.tools.formattools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/formattools/index

   .. toctree::
      :maxdepth: 1

      tools/formattools/format_lilypond_attribute
      tools/formattools/format_lilypond_value
      tools/formattools/get_all_format_contributions
      tools/formattools/get_all_mark_format_contributions
      tools/formattools/get_articulation_format_contributions
      tools/formattools/get_comment_format_contributions_for_slot
      tools/formattools/get_context_mark_format_contributions_for_slot
      tools/formattools/get_context_mark_format_pieces
      tools/formattools/get_context_setting_format_contributions
      tools/formattools/get_grob_override_format_contributions
      tools/formattools/get_grob_revert_format_contributions
      tools/formattools/get_lilypond_command_mark_format_contributions_for_slot
      tools/formattools/get_markup_format_contributions
      tools/formattools/get_spanner_format_contributions
      tools/formattools/get_stem_tremolo_format_contributions
      tools/formattools/is_formattable_context_mark_for_component
      tools/formattools/make_lilypond_override_string
      tools/formattools/make_lilypond_revert_string
      tools/formattools/report_component_format_contributions
      tools/formattools/report_spanner_format_contributions

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/formattools/format_lilypond_attribute
      tools/formattools/format_lilypond_value
      tools/formattools/get_all_format_contributions
      tools/formattools/get_all_mark_format_contributions
      tools/formattools/get_articulation_format_contributions
      tools/formattools/get_comment_format_contributions_for_slot
      tools/formattools/get_context_mark_format_contributions_for_slot
      tools/formattools/get_context_mark_format_pieces
      tools/formattools/get_context_setting_format_contributions
      tools/formattools/get_grob_override_format_contributions
      tools/formattools/get_grob_revert_format_contributions
      tools/formattools/get_lilypond_command_mark_format_contributions_for_slot
      tools/formattools/get_markup_format_contributions
      tools/formattools/get_spanner_format_contributions
      tools/formattools/get_stem_tremolo_format_contributions
      tools/formattools/is_formattable_context_mark_for_component
      tools/formattools/make_lilypond_override_string
      tools/formattools/make_lilypond_revert_string
      tools/formattools/report_component_format_contributions
      tools/formattools/report_spanner_format_contributions

:py:mod:`importtools <abjad.tools.importtools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/importtools/index

   .. toctree::
      :maxdepth: 1

      tools/importtools/ImportManager/ImportManager

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/importtools/ImportManager/ImportManager

:py:mod:`introspectiontools <abjad.tools.introspectiontools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/introspectiontools/index

   .. toctree::
      :maxdepth: 1

      tools/introspectiontools/class_to_tools_package_qualified_class_name
      tools/introspectiontools/get_current_function_name

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/introspectiontools/class_to_tools_package_qualified_class_name
      tools/introspectiontools/get_current_function_name

:py:mod:`lilypondparsertools <abjad.tools.lilypondparsertools>`
===============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/lilypondparsertools/index

   .. toctree::
      :maxdepth: 1

      tools/lilypondparsertools/Music/Music
      tools/lilypondparsertools/SimultaneousMusic/SimultaneousMusic

   .. toctree::
      :maxdepth: 1

      tools/lilypondparsertools/ContextSpeccedMusic/ContextSpeccedMusic
      tools/lilypondparsertools/GuileProxy/GuileProxy
      tools/lilypondparsertools/LilyPondDuration/LilyPondDuration
      tools/lilypondparsertools/LilyPondEvent/LilyPondEvent
      tools/lilypondparsertools/LilyPondFraction/LilyPondFraction
      tools/lilypondparsertools/LilyPondGrammarGenerator/LilyPondGrammarGenerator
      tools/lilypondparsertools/LilyPondLexicalDefinition/LilyPondLexicalDefinition
      tools/lilypondparsertools/LilyPondParser/LilyPondParser
      tools/lilypondparsertools/LilyPondSyntacticalDefinition/LilyPondSyntacticalDefinition
      tools/lilypondparsertools/ReducedLyParser/ReducedLyParser
      tools/lilypondparsertools/SchemeParser/SchemeParser
      tools/lilypondparsertools/SequentialMusic/SequentialMusic
      tools/lilypondparsertools/SyntaxNode/SyntaxNode

   .. toctree::
      :maxdepth: 1

      tools/lilypondparsertools/parse_reduced_ly_syntax

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/lilypondparsertools/Music/Music
      tools/lilypondparsertools/SimultaneousMusic/SimultaneousMusic

   Concrete classes
   ----------------

   .. toctree::

      tools/lilypondparsertools/ContextSpeccedMusic/ContextSpeccedMusic
      tools/lilypondparsertools/GuileProxy/GuileProxy
      tools/lilypondparsertools/LilyPondDuration/LilyPondDuration
      tools/lilypondparsertools/LilyPondEvent/LilyPondEvent
      tools/lilypondparsertools/LilyPondFraction/LilyPondFraction
      tools/lilypondparsertools/LilyPondGrammarGenerator/LilyPondGrammarGenerator
      tools/lilypondparsertools/LilyPondLexicalDefinition/LilyPondLexicalDefinition
      tools/lilypondparsertools/LilyPondParser/LilyPondParser
      tools/lilypondparsertools/LilyPondSyntacticalDefinition/LilyPondSyntacticalDefinition
      tools/lilypondparsertools/ReducedLyParser/ReducedLyParser
      tools/lilypondparsertools/SchemeParser/SchemeParser
      tools/lilypondparsertools/SequentialMusic/SequentialMusic
      tools/lilypondparsertools/SyntaxNode/SyntaxNode

   Functions
   ---------

   .. toctree::

      tools/lilypondparsertools/parse_reduced_ly_syntax

:py:mod:`lilypondproxytools <abjad.tools.lilypondproxytools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/lilypondproxytools/index

   .. toctree::
      :maxdepth: 1

      tools/lilypondproxytools/LilyPondComponentPlugIn/LilyPondComponentPlugIn
      tools/lilypondproxytools/LilyPondContextProxy/LilyPondContextProxy
      tools/lilypondproxytools/LilyPondContextSettingComponentPlugIn/LilyPondContextSettingComponentPlugIn
      tools/lilypondproxytools/LilyPondGrobOverrideComponentPlugIn/LilyPondGrobOverrideComponentPlugIn
      tools/lilypondproxytools/LilyPondGrobProxy/LilyPondGrobProxy
      tools/lilypondproxytools/LilyPondGrobProxyContextWrapper/LilyPondGrobProxyContextWrapper
      tools/lilypondproxytools/LilyPondObjectProxy/LilyPondObjectProxy
      tools/lilypondproxytools/LilyPondTweakReservoir/LilyPondTweakReservoir

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/lilypondproxytools/LilyPondComponentPlugIn/LilyPondComponentPlugIn
      tools/lilypondproxytools/LilyPondContextProxy/LilyPondContextProxy
      tools/lilypondproxytools/LilyPondContextSettingComponentPlugIn/LilyPondContextSettingComponentPlugIn
      tools/lilypondproxytools/LilyPondGrobOverrideComponentPlugIn/LilyPondGrobOverrideComponentPlugIn
      tools/lilypondproxytools/LilyPondGrobProxy/LilyPondGrobProxy
      tools/lilypondproxytools/LilyPondGrobProxyContextWrapper/LilyPondGrobProxyContextWrapper
      tools/lilypondproxytools/LilyPondObjectProxy/LilyPondObjectProxy
      tools/lilypondproxytools/LilyPondTweakReservoir/LilyPondTweakReservoir

:py:mod:`testtools <abjad.tools.testtools>`
===========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/testtools/index

   .. toctree::
      :maxdepth: 1

      tools/testtools/BenchmarkScoreMaker/BenchmarkScoreMaker

   .. toctree::
      :maxdepth: 1

      tools/testtools/apply_additional_layout
      tools/testtools/compare
      tools/testtools/read_test_output
      tools/testtools/write_test_output

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/testtools/BenchmarkScoreMaker/BenchmarkScoreMaker

   Functions
   ---------

   .. toctree::

      tools/testtools/apply_additional_layout
      tools/testtools/compare
      tools/testtools/read_test_output
      tools/testtools/write_test_output

:py:mod:`updatetools <abjad.tools.updatetools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/updatetools/index

   .. toctree::
      :maxdepth: 1

      tools/updatetools/UpdateManager/UpdateManager

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/updatetools/UpdateManager/UpdateManager
